/* app.c generated by valac 0.30.0.3-b11d, the Vala compiler
 * generated from app.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <libcommon.h>
#include <gtk/gtk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <config.h>
#include <gdk/gdk.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <libgd/gd.h>


#define BOXES_TYPE_BROKER (boxes_broker_get_type ())
#define BOXES_BROKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_BROKER, BoxesBroker))
#define BOXES_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_BROKER, BoxesBrokerClass))
#define BOXES_IS_BROKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_BROKER))
#define BOXES_IS_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_BROKER))
#define BOXES_BROKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_BROKER, BoxesBrokerClass))

typedef struct _BoxesBroker BoxesBroker;
typedef struct _BoxesBrokerClass BoxesBrokerClass;
typedef struct _BoxesBrokerPrivate BoxesBrokerPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;
typedef struct _BoxesCollectionPrivate BoxesCollectionPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
typedef struct _BoxesBrokerAddSourceData BoxesBrokerAddSourceData;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))

#define BOXES_TYPE_ICOLLECTION_VIEW (boxes_icollection_view_get_type ())
#define BOXES_ICOLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_ICOLLECTION_VIEW, BoxesICollectionView))
#define BOXES_IS_ICOLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_ICOLLECTION_VIEW))
#define BOXES_ICOLLECTION_VIEW_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_ICOLLECTION_VIEW, BoxesICollectionViewIface))

typedef struct _BoxesICollectionView BoxesICollectionView;
typedef struct _BoxesICollectionViewIface BoxesICollectionViewIface;

#define BOXES_TYPE_SELECTION_CRITERIA (boxes_selection_criteria_get_type ())

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _Block1Data Block1Data;
typedef struct _Block2Data Block2Data;

#define BOXES_TYPE_LIBVIRT_BROKER (boxes_libvirt_broker_get_type ())
#define BOXES_LIBVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBroker))
#define BOXES_LIBVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBrokerClass))
#define BOXES_IS_LIBVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_BROKER))
#define BOXES_IS_LIBVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_BROKER))
#define BOXES_LIBVIRT_BROKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBrokerClass))

typedef struct _BoxesLibvirtBroker BoxesLibvirtBroker;
typedef struct _BoxesLibvirtBrokerClass BoxesLibvirtBrokerClass;

#define BOXES_TYPE_OVIRT_BROKER (boxes_ovirt_broker_get_type ())
#define BOXES_OVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_OVIRT_BROKER, BoxesOvirtBroker))
#define BOXES_OVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_OVIRT_BROKER, BoxesOvirtBrokerClass))
#define BOXES_IS_OVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_OVIRT_BROKER))
#define BOXES_IS_OVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_OVIRT_BROKER))
#define BOXES_OVIRT_BROKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_OVIRT_BROKER, BoxesOvirtBrokerClass))

typedef struct _BoxesOvirtBroker BoxesOvirtBroker;
typedef struct _BoxesOvirtBrokerClass BoxesOvirtBrokerClass;
typedef struct _Block3Data Block3Data;
typedef struct _Block4Data Block4Data;
#define _g_option_context_free0(var) ((var == NULL) ? NULL : (var = (g_option_context_free (var), NULL)))
typedef struct _Block5Data Block5Data;
typedef struct _Block6Data Block6Data;
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_WIZARD_WINDOW (boxes_wizard_window_get_type ())
#define BOXES_WIZARD_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindow))
#define BOXES_WIZARD_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindowClass))
#define BOXES_IS_WIZARD_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_WINDOW))
#define BOXES_IS_WIZARD_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_WINDOW))
#define BOXES_WIZARD_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindowClass))

typedef struct _BoxesWizardWindow BoxesWizardWindow;
typedef struct _BoxesWizardWindowClass BoxesWizardWindowClass;

#define BOXES_TYPE_PROPERTIES_WINDOW (boxes_properties_window_get_type ())
#define BOXES_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindow))
#define BOXES_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))
#define BOXES_IS_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_IS_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_PROPERTIES_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))

typedef struct _BoxesPropertiesWindow BoxesPropertiesWindow;
typedef struct _BoxesPropertiesWindowClass BoxesPropertiesWindowClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;
typedef struct _BoxesWizardWindowPrivate BoxesWizardWindowPrivate;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_WIZARD_TOOLBAR (boxes_wizard_toolbar_get_type ())
#define BOXES_WIZARD_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbar))
#define BOXES_WIZARD_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbarClass))
#define BOXES_IS_WIZARD_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_TOOLBAR))
#define BOXES_IS_WIZARD_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_TOOLBAR))
#define BOXES_WIZARD_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbarClass))

typedef struct _BoxesWizardToolbar BoxesWizardToolbar;
typedef struct _BoxesWizardToolbarClass BoxesWizardToolbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REMOTE_MACHINE (boxes_remote_machine_get_type ())
#define BOXES_REMOTE_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachine))
#define BOXES_REMOTE_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachineClass))
#define BOXES_IS_REMOTE_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REMOTE_MACHINE))
#define BOXES_IS_REMOTE_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REMOTE_MACHINE))
#define BOXES_REMOTE_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachineClass))

typedef struct _BoxesRemoteMachine BoxesRemoteMachine;
typedef struct _BoxesRemoteMachineClass BoxesRemoteMachineClass;
typedef struct _BoxesAppAddCollectionSourceData BoxesAppAddCollectionSourceData;
typedef struct _BoxesAppSetupDefaultSourceData BoxesAppSetupDefaultSourceData;
typedef struct _Block7Data Block7Data;
typedef struct _BoxesAppSetupSourcesData BoxesAppSetupSourcesData;
typedef struct _Block8Data Block8Data;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;
typedef struct _Block9Data Block9Data;
#define _g_main_context_unref0(var) ((var == NULL) ? NULL : (var = (g_main_context_unref (var), NULL)))
typedef struct _Block10Data Block10Data;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _BoxesBroker {
	GObject parent_instance;
	BoxesBrokerPrivate * priv;
};

struct _BoxesBrokerClass {
	GObjectClass parent_class;
	void (*add_source) (BoxesBroker* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*add_source_finish) (BoxesBroker* self, GAsyncResult* _res_);
};

struct _BoxesApp {
	GtkApplication parent_instance;
	BoxesAppPrivate * priv;
	BoxesCollection* collection;
};

struct _BoxesAppClass {
	GtkApplicationClass parent_class;
};

struct _BoxesCollection {
	GObject parent_instance;
	BoxesCollectionPrivate * priv;
	GPtrArray* items;
};

struct _BoxesCollectionClass {
	GObjectClass parent_class;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_GENERAL,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*update_status) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
	gboolean (*get_suspend_at_exit) (BoxesMachine* self);
	gboolean (*get_can_save) (BoxesMachine* self);
	gboolean (*get_should_autosave) (BoxesMachine* self);
	gboolean (*get_is_local) (BoxesMachine* self);
};

struct _BoxesBrokerAddSourceData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesBroker* self;
	BoxesCollectionSource* source;
	GList* used_configs;
	BoxesApp* _tmp0_;
	BoxesCollection* _tmp1_;
	GPtrArray* _tmp2_;
	gpointer* _tmp3_;
	gint _tmp3__length1;
	BoxesCollectionItem** item_collection;
	gint item_collection_length1;
	gint _item_collection_size_;
	gint item_it;
	BoxesCollectionItem* _tmp4_;
	BoxesCollectionItem* item;
	BoxesCollectionItem* _tmp5_;
	BoxesCollectionItem* _tmp6_;
	BoxesBoxConfig* _tmp7_;
	BoxesBoxConfig* _tmp8_;
	BoxesCollectionSource* _tmp9_;
	GList* _tmp10_;
};

struct _BoxesAppPrivate {
	GList* windows;
	gchar* _uri;
	gboolean is_ready;
	GHashTable* brokers;
	GHashTable* sources;
};

typedef enum  {
	BOXES_SELECTION_CRITERIA_ALL,
	BOXES_SELECTION_CRITERIA_NONE,
	BOXES_SELECTION_CRITERIA_RUNNING
} BoxesSelectionCriteria;

struct _BoxesICollectionViewIface {
	GTypeInterface parent_iface;
	void (*add_item) (BoxesICollectionView* self, BoxesCollectionItem* item);
	void (*remove_item) (BoxesICollectionView* self, BoxesCollectionItem* item);
	GList* (*get_selected_items) (BoxesICollectionView* self);
	void (*activate_first_item) (BoxesICollectionView* self);
	void (*select_by_criteria) (BoxesICollectionView* self, BoxesSelectionCriteria criteria);
	BoxesCollectionFilter* (*get_filter) (BoxesICollectionView* self);
	void (*set_filter) (BoxesICollectionView* self, BoxesCollectionFilter* value);
};

struct _Block1Data {
	int _ref_count_;
	BoxesApp* self;
	BoxesCollectionItem* item;
};

struct _Block2Data {
	int _ref_count_;
	BoxesApp* self;
	BoxesCollectionItem* item;
};

typedef void (*BoxesAppCallReadyFunc) (void* user_data);
struct _Block3Data {
	int _ref_count_;
	BoxesApp* self;
	BoxesAppCallReadyFunc func;
	gpointer func_target;
	GDestroyNotify func_target_destroy_notify;
};

struct _Block4Data {
	int _ref_count_;
	BoxesApp* self;
	BoxesApp* app;
};

struct _Block5Data {
	int _ref_count_;
	Block4Data * _data4_;
	gchar* uuid;
};

struct _Block6Data {
	int _ref_count_;
	Block4Data * _data4_;
	gchar* arg;
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesWizardWindow* wizard_window;
	BoxesPropertiesWindow* props_window;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesSelectionbar* selectionbar;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

struct _BoxesWizardWindow {
	GtkWindow parent_instance;
	BoxesWizardWindowPrivate * priv;
	GtkStack* view;
	BoxesWizard* wizard;
	GtkGrid* customization_grid;
	GtkFileChooserWidget* file_chooser;
	BoxesWizardToolbar* topbar;
	BoxesNotificationbar* notificationbar;
};

struct _BoxesWizardWindowClass {
	GtkWindowClass parent_class;
};

struct _BoxesAppAddCollectionSourceData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesApp* self;
	BoxesCollectionSource* source;
	BoxesCollectionSource* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	GHashTable* _tmp3_;
	BoxesCollectionSource* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gconstpointer _tmp8_;
	gboolean _tmp9_;
	BoxesCollectionSource* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	BoxesCollectionSource* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	GQuark _tmp19_;
	BoxesRemoteMachine* machine;
	BoxesCollectionSource* _tmp20_;
	BoxesRemoteMachine* _tmp21_;
	BoxesCollection* _tmp22_;
	BoxesRemoteMachine* _tmp23_;
	GError* _error_;
	GError* _tmp24_;
	const gchar* _tmp25_;
	BoxesBroker* broker;
	GHashTable* _tmp26_;
	BoxesCollectionSource* _tmp27_;
	gchar* _tmp28_;
	gchar* _tmp29_;
	gchar* _tmp30_;
	gconstpointer _tmp31_;
	BoxesBroker* _tmp32_;
	BoxesBroker* _tmp33_;
	BoxesBroker* _tmp34_;
	BoxesBroker* _tmp35_;
	BoxesCollectionSource* _tmp36_;
	GHashTable* _tmp37_;
	BoxesCollectionSource* _tmp38_;
	gchar* _tmp39_;
	gchar* _tmp40_;
	BoxesCollectionSource* _tmp41_;
	BoxesCollectionSource* _tmp42_;
	BoxesCollectionSource* _tmp43_;
	gchar* _tmp44_;
	gchar* _tmp45_;
	gchar* _tmp46_;
	gboolean _tmp47_;
	BoxesCollectionSource* _tmp48_;
	gchar* _tmp49_;
	gchar* _tmp50_;
	gchar* _tmp51_;
	GError * _inner_error_;
};

struct _BoxesAppSetupDefaultSourceData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesApp* self;
	gchar* path;
	gchar* _tmp0_;
	gboolean create_session_source;
	GFile* file;
	GFile* _tmp1_;
	GFileInfo* info;
	GFileInfo* _tmp2_;
	guint64 _tmp3_;
	GError* _error_;
	GError* _tmp4_;
	const gchar* _tmp5_;
	gboolean _tmp6_;
	GFile* src;
	gchar* _tmp7_;
	gchar* _tmp8_;
	GFile* _tmp9_;
	GFile* _tmp10_;
	GFile* dst;
	GFile* _tmp11_;
	GFile* _tmp12_;
	GFile* _tmp13_;
	GError* _vala1__error_;
	GError* _tmp14_;
	const gchar* _tmp15_;
	BoxesCollectionSource* source;
	BoxesCollectionSource* _tmp16_;
	GError* _vala2__error_;
	GError* _tmp17_;
	const gchar* _tmp18_;
	GVirConnection* _tmp19_;
	GVirConnection* _tmp20_;
	GVirConnection* _tmp21_;
	GError * _inner_error_;
};

struct _Block7Data {
	int _ref_count_;
	BoxesApp* self;
	GList* new_sources;
	gpointer _async_data_;
};

struct _BoxesAppSetupSourcesData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesApp* self;
	Block7Data* _data7_;
	GFile* dir;
	gchar* _tmp0_;
	gchar* _tmp1_;
	GFile* _tmp2_;
	GFile* _tmp3_;
	GFile* _tmp4_;
	GList* _tmp5_;
	GList* source_collection;
	GList* source_it;
	BoxesCollectionSource* _tmp6_;
	BoxesCollectionSource* source;
	BoxesCollectionSource* _tmp7_;
	GVirConnection* _tmp8_;
	GVirConnection* _tmp9_;
	GVirConnection* _tmp10_;
	gboolean _tmp11_;
};

struct _Block8Data {
	int _ref_count_;
	BoxesApp* self;
	gint waiting_counter;
};

struct _Block9Data {
	int _ref_count_;
	Block8Data * _data8_;
	BoxesLibvirtMachine* machine;
};

typedef void (*BoxesAppUndoNotifyCallback) (void* user_data);
struct _Block10Data {
	int _ref_count_;
	BoxesApp* self;
	GList* items;
	BoxesAppUndoNotifyCallback undo_notify_callback;
	gpointer undo_notify_callback_target;
	GDestroyNotify undo_notify_callback_target_destroy_notify;
};

typedef void (*BoxesNotificationOKFunc) (void* user_data);
typedef void (*BoxesNotificationCancelFunc) (void* user_data);

static gpointer boxes_broker_parent_class = NULL;
extern BoxesApp* boxes_app_app;
static gpointer boxes_app_parent_class = NULL;
BoxesApp* boxes_app_app = NULL;
static gboolean boxes_app_opt_fullscreen;
static gboolean boxes_app_opt_fullscreen = FALSE;
static gboolean boxes_app_opt_help;
static gboolean boxes_app_opt_help = FALSE;
static gchar* boxes_app_opt_open_uuid;
static gchar* boxes_app_opt_open_uuid = NULL;
static gchar** boxes_app_opt_uris;
static gint boxes_app_opt_uris_length1;
static gchar** boxes_app_opt_uris = NULL;
static gint boxes_app_opt_uris_length1 = 0;
static gint _boxes_app_opt_uris_size_ = 0;
static gchar** boxes_app_opt_search;
static gint boxes_app_opt_search_length1;
static gchar** boxes_app_opt_search = NULL;
static gint boxes_app_opt_search_length1 = 0;
static gint _boxes_app_opt_search_size_ = 0;

GType boxes_broker_get_type (void) G_GNUC_CONST;
enum  {
	BOXES_BROKER_DUMMY_PROPERTY
};
static void boxes_broker_real_add_source_data_free (gpointer _data);
static void boxes_broker_real_add_source (BoxesBroker* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_broker_add_source (BoxesBroker* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_broker_add_source_finish (BoxesBroker* self, GAsyncResult* _res_);
static gboolean boxes_broker_real_add_source_co (BoxesBrokerAddSourceData* _data_);
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
BoxesBroker* boxes_broker_construct (GType object_type);
GType boxes_app_window_get_type (void) G_GNUC_CONST;
#define BOXES_APP_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_APP, BoxesAppPrivate))
enum  {
	BOXES_APP_DUMMY_PROPERTY,
	BOXES_APP_MAIN_WINDOW,
	BOXES_APP_URI,
	BOXES_APP_DEFAULT_CONNECTION,
	BOXES_APP_DEFAULT_SOURCE,
	BOXES_APP_SELECTED_ITEMS
};
#define BOXES_APP_DEFAULT_SOURCE_NAME "QEMU Session"
BoxesApp* boxes_app_new (void);
BoxesApp* boxes_app_construct (GType object_type);
static void _g_free0_ (gpointer var);
static void __lambda229_ (BoxesApp* self);
gboolean boxes_app_quit_app (BoxesApp* self);
static void ___lambda229__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self);
static void __lambda230_ (BoxesApp* self);
BoxesAppWindow* boxes_app_get_main_window (BoxesApp* self);
GType boxes_selection_criteria_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_icollection_view_get_type (void) G_GNUC_CONST;
BoxesICollectionView* boxes_app_window_get_view (BoxesAppWindow* self);
void boxes_icollection_view_select_by_criteria (BoxesICollectionView* self, BoxesSelectionCriteria criteria);
static void ___lambda230__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self);
static void __lambda231_ (BoxesApp* self);
static void ___lambda231__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self);
static void __lambda232_ (BoxesApp* self);
static void ___lambda232__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self);
static void __lambda233_ (BoxesApp* self);
static void ___lambda233__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self);
static void __lambda234_ (BoxesApp* self, GVariant* param);
void boxes_app_open_name (BoxesApp* self, const gchar* name);
static void ___lambda234__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self);
static void __lambda235_ (BoxesApp* self);
static void ___lambda235__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self);
static void boxes_app_real_startup (GApplication* base);
BoxesCollection* boxes_collection_new (void);
BoxesCollection* boxes_collection_construct (GType object_type);
static void __lambda236_ (BoxesApp* self, BoxesCollectionItem* item);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
void boxes_app_window_foreach_view (BoxesAppWindow* self, GFunc func, void* func_target);
static void __lambda237_ (Block1Data* _data1_, BoxesICollectionView* view);
void boxes_icollection_view_add_item (BoxesICollectionView* self, BoxesCollectionItem* item);
static void ___lambda237__gfunc (gconstpointer data, gpointer self);
static void ___lambda236__boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
static void __lambda238_ (BoxesApp* self, BoxesCollectionItem* item);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
static void __lambda239_ (Block2Data* _data2_, BoxesICollectionView* view);
void boxes_icollection_view_remove_item (BoxesICollectionView* self, BoxesCollectionItem* item);
static void ___lambda239__gfunc (gconstpointer data, gpointer self);
static void ___lambda238__boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
GType boxes_libvirt_broker_get_type (void) G_GNUC_CONST;
BoxesLibvirtBroker* boxes_libvirt_broker_get_default (void);
GType boxes_ovirt_broker_get_type (void) G_GNUC_CONST;
BoxesOvirtBroker* boxes_ovirt_broker_get_default (void);
void boxes_check_cpu_vt_capability (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_cpu_vt_capability_finish (GAsyncResult* _res_);
void boxes_check_module_kvm_loaded (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_module_kvm_loaded_finish (GAsyncResult* _res_);
gboolean boxes_app_has_broker_for_source_type (BoxesApp* self, const gchar* type);
void boxes_app_call_when_ready (BoxesApp* self, BoxesAppCallReadyFunc func, void* func_target, GDestroyNotify func_target_destroy_notify);
static Block3Data* block3_data_ref (Block3Data* _data3_);
static void block3_data_unref (void * _userdata_);
static void __lambda19_ (Block3Data* _data3_);
static void ___lambda19__boxes_app_ready (BoxesApp* _sender, gpointer self);
static void boxes_app_real_activate (GApplication* base);
BoxesAppWindow* boxes_app_add_new_window (BoxesApp* self);
void boxes_ui_set_state (BoxesUI* self, BoxesUIState new_state);
static void boxes_app_setup_default_source (BoxesApp* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_app_setup_default_source_finish (BoxesApp* self, GAsyncResult* _res_);
static void __lambda243_ (BoxesApp* self, GObject* obj, GAsyncResult* _result_);
static void boxes_app_setup_sources (BoxesApp* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_app_setup_sources_finish (BoxesApp* self, GAsyncResult* _res_);
static void ___lambda243__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gint boxes_app_real_command_line (GApplication* base, GApplicationCommandLine* cmdline);
static Block4Data* block4_data_ref (Block4Data* _data4_);
static void block4_data_unref (void * _userdata_);
static Block5Data* block5_data_ref (Block5Data* _data5_);
static void block5_data_unref (void * _userdata_);
static void ___lambda245_ (Block5Data* _data5_);
gboolean boxes_app_open_uuid (BoxesApp* self, const gchar* uuid);
static void ____lambda245__boxes_app_call_ready_func (gpointer self);
static Block6Data* block6_data_ref (Block6Data* _data6_);
static void block6_data_unref (void * _userdata_);
static void ____lambda246_ (Block6Data* _data6_);
GType boxes_wizard_window_get_type (void) G_GNUC_CONST;
GType boxes_properties_window_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_wizard_toolbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
void boxes_wizard_open_with_uri (BoxesWizard* self, const gchar* uri, gboolean skip_review_for_live);
static void _____lambda246__boxes_app_call_ready_func (gpointer self);
static void ___lambda247_ (BoxesApp* self);
void boxes_searchbar_set_text (BoxesSearchbar* self, const gchar* value);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
static void ____lambda247__boxes_app_call_ready_func (gpointer self);
void boxes_app_window_set_fullscreened (BoxesAppWindow* self, gboolean value);
static gboolean __lambda25_ (BoxesApp* self);
static gboolean ___lambda25__gsource_func (gpointer self);
static void boxes_app_real_shutdown (GApplication* base);
BoxesNotificationbar* boxes_app_window_get_notificationbar (BoxesAppWindow* self);
void boxes_notificationbar_cancel (BoxesNotificationbar* self);
void boxes_wizard_cleanup (BoxesWizard* self);
static void boxes_app_suspend_machines (BoxesApp* self);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
void boxes_app_window_select_item (BoxesAppWindow* self, BoxesCollectionItem* item);
void boxes_app_open_selected_items_in_new_window (BoxesApp* self);
GList* boxes_icollection_view_get_selected_items (BoxesICollectionView* self);
void boxes_app_window_set_selection_mode (BoxesAppWindow* self, gboolean value);
void boxes_app_open_in_new_window (BoxesApp* self, BoxesMachine* machine);
BoxesAppWindow* boxes_machine_get_window (BoxesMachine* self);
void boxes_app_window_connect_to (BoxesAppWindow* self, BoxesMachine* machine);
void boxes_app_delete_machine (BoxesApp* self, BoxesMachine* machine, gboolean by_user);
void boxes_machine_delete (BoxesMachine* self, gboolean by_user);
void boxes_collection_remove_item (BoxesCollection* self, BoxesCollectionItem* item);
static void boxes_app_add_collection_source_data_free (gpointer _data);
void boxes_app_add_collection_source (BoxesApp* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_app_add_collection_source_finish (BoxesApp* self, GAsyncResult* _res_);
static gboolean boxes_app_add_collection_source_co (BoxesAppAddCollectionSourceData* _data_);
GType boxes_remote_machine_get_type (void) G_GNUC_CONST;
BoxesRemoteMachine* boxes_remote_machine_new (BoxesCollectionSource* source, GError** error);
BoxesRemoteMachine* boxes_remote_machine_construct (GType object_type, BoxesCollectionSource* source, GError** error);
void boxes_collection_add_item (BoxesCollection* self, BoxesCollectionItem* item);
static void boxes_app_add_collection_source_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_app_setup_default_source_data_free (gpointer _data);
static gboolean boxes_app_setup_default_source_co (BoxesAppSetupDefaultSourceData* _data_);
static void boxes_app_setup_default_source_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GVirConnection* boxes_app_get_default_connection (BoxesApp* self);
void boxes_app_notify_machine_installed (BoxesApp* self, BoxesMachine* machine);
static void boxes_app_setup_sources_data_free (gpointer _data);
static gboolean boxes_app_setup_sources_co (BoxesAppSetupSourcesData* _data_);
static Block7Data* block7_data_ref (Block7Data* _data7_);
static void block7_data_unref (void * _userdata_);
static gboolean __lambda244_ (Block7Data* _data7_, const gchar* filename, GError** error);
static gboolean ___lambda244__boxes_foreach_filename_from_dir_func (const gchar* filename, gpointer self, GError** error);
static void boxes_app_setup_sources_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static Block8Data* block8_data_ref (Block8Data* _data8_);
static void block8_data_unref (void * _userdata_);
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
static Block9Data* block9_data_ref (Block9Data* _data9_);
static void block9_data_unref (void * _userdata_);
gboolean boxes_machine_get_suspend_at_exit (BoxesMachine* self);
void boxes_libvirt_machine_suspend (BoxesLibvirtMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_libvirt_machine_suspend_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_, GError** error);
static void ______lambda248_ (Block9Data* _data9_);
static void _______lambda248__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
void boxes_app_delete_machines_undoable (BoxesApp* self, GList* items, const gchar* message, BoxesAppUndoNotifyCallback undo_notify_callback, void* undo_notify_callback_target, GDestroyNotify undo_notify_callback_target_destroy_notify);
static Block10Data* block10_data_ref (Block10Data* _data10_);
static void block10_data_unref (void * _userdata_);
static void __lambda85_ (Block10Data* _data10_);
static void ___lambda85__boxes_notification_ok_func (gpointer self);
static void __lambda86_ (Block10Data* _data10_);
static void ___lambda86__boxes_notification_cancel_func (gpointer self);
GdNotification* boxes_notificationbar_display_for_action (BoxesNotificationbar* self, const gchar* message, const gchar* action_label, BoxesNotificationOKFunc action_func, void* action_func_target, GDestroyNotify action_func_target_destroy_notify, BoxesNotificationCancelFunc ignore_func, void* ignore_func_target, GDestroyNotify ignore_func_target_destroy_notify, gint timeout);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
void boxes_app_remove_selected_items (BoxesApp* self);
BoxesAppWindow* boxes_app_window_new (GtkApplication* app);
BoxesAppWindow* boxes_app_window_construct (GType object_type, GtkApplication* app);
void boxes_app_window_setup_ui (BoxesAppWindow* self);
gboolean boxes_app_remove_window (BoxesApp* self, BoxesAppWindow* window);
BoxesCollectionItem* boxes_app_window_get_current_item (BoxesAppWindow* self);
void boxes_machine_set_window (BoxesMachine* self, BoxesAppWindow* value);
static void ___lambda26_ (BoxesApp* self, BoxesICollectionView* view);
void boxes_collection_populate (BoxesCollection* self, BoxesICollectionView* view);
static void ____lambda26__gfunc (gconstpointer data, gpointer self);
const gchar* boxes_app_get_uri (BoxesApp* self);
void boxes_app_set_uri (BoxesApp* self, const gchar* value);
GVirConnection* boxes_libvirt_broker_get_connection (BoxesLibvirtBroker* self, const gchar* name);
BoxesCollectionSource* boxes_app_get_default_source (BoxesApp* self);
GList* boxes_app_get_selected_items (BoxesApp* self);
static void boxes_app_finalize (GObject* obj);
static void _vala_boxes_app_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_app_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);

static const GOptionEntry BOXES_APP_options[8] = {{"version", (gchar) 0, 0, G_OPTION_ARG_NONE, NULL, "Display version number", NULL}, {"help", 'h', (gint) G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, &boxes_app_opt_help, NULL, NULL}, {"full-screen", 'f', 0, G_OPTION_ARG_NONE, &boxes_app_opt_fullscreen, "Open in full screen", NULL}, {"checks", (gchar) 0, 0, G_OPTION_ARG_NONE, NULL, "Check virtualization capabilities", NULL}, {"open-uuid", (gchar) 0, 0, G_OPTION_ARG_STRING, &boxes_app_opt_open_uuid, "Open box with UUID", NULL}, {"search", (gchar) 0, 0, G_OPTION_ARG_STRING_ARRAY, &boxes_app_opt_search, "Search term", NULL}, {"", (gchar) 0, 0, G_OPTION_ARG_STRING_ARRAY, &boxes_app_opt_uris, "URI to display, broker or installer media", NULL}, {NULL}};

static void boxes_broker_real_add_source_data_free (gpointer _data) {
	BoxesBrokerAddSourceData* _data_;
	_data_ = _data;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->source);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->self);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_slice_free (BoxesBrokerAddSourceData, _data_);
#line 941 "app.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return self ? g_object_ref (self) : NULL;
#line 948 "app.c"
}


static void boxes_broker_real_add_source (BoxesBroker* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesBrokerAddSourceData* _data_;
	BoxesBroker* _tmp0_ = NULL;
	BoxesCollectionSource* _tmp1_ = NULL;
	BoxesCollectionSource* _tmp2_ = NULL;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = g_slice_new0 (BoxesBrokerAddSourceData);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_broker_real_add_source);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_broker_real_add_source_data_free);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->self = _tmp0_;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = source;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->source);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->source = _tmp2_;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_broker_real_add_source_co (_data_);
#line 977 "app.c"
}


static void boxes_broker_real_add_source_finish (BoxesBroker* self, GAsyncResult* _res_) {
	BoxesBrokerAddSourceData* _data_;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 985 "app.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 992 "app.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_list_free (self);
#line 1001 "app.c"
}


static gboolean boxes_broker_real_add_source_co (BoxesBrokerAddSourceData* _data_) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	switch (_data_->_state_) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case 0:
#line 1010 "app.c"
		goto _state_0;
		default:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_assert_not_reached ();
#line 1015 "app.c"
	}
	_state_0:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->used_configs = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp0_ = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp0_ = boxes_app_app;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp1_ = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp1_ = _data_->_tmp0_->collection;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp2_ = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp2_ = _data_->_tmp1_->items;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp3_ = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp3__length1 = 0;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp3_ = _data_->_tmp2_->pdata;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp3__length1 = (gint) _data_->_tmp2_->len;
#line 1040 "app.c"
	{
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->item_collection_length1 = 0;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_item_collection_size_ = 0;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->item_collection = _data_->_tmp3_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->item_collection_length1 = _data_->_tmp3__length1;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		for (_data_->item_it = 0; _data_->item_it < _data_->_tmp3__length1; _data_->item_it = _data_->item_it + 1) {
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp4_ = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp4_ = _g_object_ref0 (_data_->item_collection[_data_->item_it]);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->item = _data_->_tmp4_;
#line 1058 "app.c"
			{
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp5_ = NULL;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp5_ = _data_->item;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				if (!G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp5_, BOXES_TYPE_MACHINE)) {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_g_object_unref0 (_data_->item);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					continue;
#line 1070 "app.c"
				}
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp6_ = NULL;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp6_ = _data_->item;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp7_ = NULL;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp7_ = (G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp6_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _data_->_tmp6_) : NULL)->config;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp8_ = NULL;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp8_ = _g_object_ref0 (_data_->_tmp7_);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->used_configs = g_list_append (_data_->used_configs, _data_->_tmp8_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (_data_->item);
#line 1088 "app.c"
			}
		}
	}
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp9_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp9_ = _data_->source;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp10_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp10_ = _data_->used_configs;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_collection_source_purge_stale_box_configs (_data_->_tmp9_, _data_->_tmp10_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__g_list_free__g_object_unref0_0 (_data_->used_configs);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_data_->_state_ == 0) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1108 "app.c"
	} else {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1112 "app.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_unref (_data_->_async_result);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return FALSE;
#line 1118 "app.c"
}


void boxes_broker_add_source (BoxesBroker* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	BOXES_BROKER_GET_CLASS (self)->add_source (self, source, _callback_, _user_data_);
#line 1125 "app.c"
}


void boxes_broker_add_source_finish (BoxesBroker* self, GAsyncResult* _res_) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	BOXES_BROKER_GET_CLASS (self)->add_source_finish (self, _res_);
#line 1132 "app.c"
}


BoxesBroker* boxes_broker_construct (GType object_type) {
	BoxesBroker * self = NULL;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = (BoxesBroker*) g_object_new (object_type, NULL);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return self;
#line 1142 "app.c"
}


static void boxes_broker_class_init (BoxesBrokerClass * klass) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_broker_parent_class = g_type_class_peek_parent (klass);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	((BoxesBrokerClass *) klass)->add_source = boxes_broker_real_add_source;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	((BoxesBrokerClass *) klass)->add_source_finish = boxes_broker_real_add_source_finish;
#line 1153 "app.c"
}


static void boxes_broker_instance_init (BoxesBroker * self) {
}


GType boxes_broker_get_type (void) {
	static volatile gsize boxes_broker_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_broker_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesBrokerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_broker_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesBroker), 0, (GInstanceInitFunc) boxes_broker_instance_init, NULL };
		GType boxes_broker_type_id;
		boxes_broker_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesBroker", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&boxes_broker_type_id__volatile, boxes_broker_type_id);
	}
	return boxes_broker_type_id__volatile;
}


static void _g_free0_ (gpointer var) {
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	var = (g_free (var), NULL);
#line 1176 "app.c"
}


static void __lambda229_ (BoxesApp* self) {
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_quit_app (self);
#line 1183 "app.c"
}


static void ___lambda229__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self) {
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda229_ ((BoxesApp*) self);
#line 1190 "app.c"
}


static void __lambda230_ (BoxesApp* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesICollectionView* _tmp2_ = NULL;
	BoxesICollectionView* _tmp3_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_get_main_window (self);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = boxes_app_window_get_view (_tmp1_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = _tmp2_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_icollection_view_select_by_criteria (_tmp3_, BOXES_SELECTION_CRITERIA_ALL);
#line 1209 "app.c"
}


static void ___lambda230__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self) {
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda230_ ((BoxesApp*) self);
#line 1216 "app.c"
}


static void __lambda231_ (BoxesApp* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesICollectionView* _tmp2_ = NULL;
	BoxesICollectionView* _tmp3_ = NULL;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_get_main_window (self);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = boxes_app_window_get_view (_tmp1_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = _tmp2_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_icollection_view_select_by_criteria (_tmp3_, BOXES_SELECTION_CRITERIA_RUNNING);
#line 1235 "app.c"
}


static void ___lambda231__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self) {
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda231_ ((BoxesApp*) self);
#line 1242 "app.c"
}


static void __lambda232_ (BoxesApp* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesICollectionView* _tmp2_ = NULL;
	BoxesICollectionView* _tmp3_ = NULL;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_get_main_window (self);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = boxes_app_window_get_view (_tmp1_);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = _tmp2_;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_icollection_view_select_by_criteria (_tmp3_, BOXES_SELECTION_CRITERIA_NONE);
#line 1261 "app.c"
}


static void ___lambda232__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self) {
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda232_ ((BoxesApp*) self);
#line 1268 "app.c"
}


static void __lambda233_ (BoxesApp* self) {
	GError * _inner_error_ = NULL;
	{
		BoxesAppWindow* _tmp0_ = NULL;
		BoxesAppWindow* _tmp1_ = NULL;
		GdkScreen* _tmp2_ = NULL;
		guint32 _tmp3_ = 0U;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp0_ = boxes_app_get_main_window (self);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp1_ = _tmp0_;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp2_ = gtk_window_get_screen ((GtkWindow*) _tmp1_);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp3_ = gtk_get_current_event_time ();
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		gtk_show_uri (_tmp2_, "help:gnome-boxes", _tmp3_, &_inner_error_);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1291 "app.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		e = _inner_error_;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_inner_error_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp4_ = e;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp5_ = _tmp4_->message;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_warning ("app.vala:74: Failed to display help: %s", _tmp5_);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_error_free0 (e);
#line 1313 "app.c"
	}
	__finally0:
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_clear_error (&_inner_error_);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return;
#line 1324 "app.c"
	}
}


static void ___lambda233__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self) {
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda233_ ((BoxesApp*) self);
#line 1332 "app.c"
}


static void __lambda234_ (BoxesApp* self, GVariant* param) {
	GVariant* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = param;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = g_variant_get_string (_tmp0_, NULL);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_open_name (self, _tmp1_);
#line 1345 "app.c"
}


static void ___lambda234__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self) {
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda234_ ((BoxesApp*) self, parameter);
#line 1352 "app.c"
}


static void __lambda235_ (BoxesApp* self) {
	gchar** authors = NULL;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar** _tmp4_ = NULL;
	gint authors_length1 = 0;
	gint _authors_size_ = 0;
	gchar** artists = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar** _tmp9_ = NULL;
	gint artists_length1 = 0;
	gint _artists_size_ = 0;
	BoxesAppWindow* _tmp10_ = NULL;
	BoxesAppWindow* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
	const gchar* _tmp13_ = NULL;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = g_strdup ("Alexander Larsson <alexl@redhat.com>");
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = g_strdup ("Christophe Fergeau <cfergeau@redhat.com>");
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = g_strdup ("Marc-André Lureau <marcandre.lureau@gmail.com>");
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = g_strdup ("Zeeshan Ali (Khattak) <zeeshanak@gnome.org>");
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = g_new0 (gchar*, 4 + 1);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_[0] = _tmp0_;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_[1] = _tmp1_;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_[2] = _tmp2_;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_[3] = _tmp3_;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	authors = _tmp4_;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	authors_length1 = 4;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_authors_size_ = authors_length1;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = g_strdup ("Allan Day <aday@gnome.org>");
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = g_strdup ("Jon McCann <jmccann@redhat.com>");
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = g_strdup ("Jakub Steiner <jsteiner@redhat.com>");
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp8_ = g_strdup ("Dave Jones <eevblog@yahoo.com.au>");
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp9_ = g_new0 (gchar*, 4 + 1);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp9_[0] = _tmp5_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp9_[1] = _tmp6_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp9_[2] = _tmp7_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp9_[3] = _tmp8_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	artists = _tmp9_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	artists_length1 = 4;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_artists_size_ = artists_length1;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp10_ = boxes_app_get_main_window (self);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp11_ = _tmp10_;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp12_ = _ ("translator-credits");
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp13_ = _ ("A simple GNOME 3 application to access remote or virtual systems");
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_show_about_dialog ((GtkWindow*) _tmp11_, "artists", artists, "authors", authors, "translator-credits", _tmp12_, "comments", _tmp13_, "copyright", "Copyright 2011 Red Hat, Inc.", "license-type", GTK_LICENSE_LGPL_2_1, "logo-icon-name", "gnome-boxes", "version", VERSION, "website", PACKAGE_URL, "wrap-license", TRUE, NULL);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	artists = (_vala_array_free (artists, artists_length1, (GDestroyNotify) g_free), NULL);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	authors = (_vala_array_free (authors, authors_length1, (GDestroyNotify) g_free), NULL);
#line 1439 "app.c"
}


static void ___lambda235__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self) {
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda235_ ((BoxesApp*) self);
#line 1446 "app.c"
}


BoxesApp* boxes_app_construct (GType object_type) {
	BoxesApp * self = NULL;
	GApplicationFlags _tmp0_ = 0;
	GApplicationFlags _tmp1_ = 0;
	BoxesApp* _tmp2_ = NULL;
	GHashFunc _tmp3_ = NULL;
	GEqualFunc _tmp4_ = NULL;
	GHashTable* _tmp5_ = NULL;
	GHashFunc _tmp6_ = NULL;
	GEqualFunc _tmp7_ = NULL;
	GHashTable* _tmp8_ = NULL;
	GSimpleAction* action = NULL;
	GSimpleAction* _tmp9_ = NULL;
	GSimpleAction* _tmp10_ = NULL;
	GSimpleAction* _tmp11_ = NULL;
	GSimpleAction* _tmp12_ = NULL;
	GSimpleAction* _tmp13_ = NULL;
	GSimpleAction* _tmp14_ = NULL;
	GSimpleAction* _tmp15_ = NULL;
	GSimpleAction* _tmp16_ = NULL;
	GSimpleAction* _tmp17_ = NULL;
	GSimpleAction* _tmp18_ = NULL;
	GSimpleAction* _tmp19_ = NULL;
	GSimpleAction* _tmp20_ = NULL;
	GSimpleAction* _tmp21_ = NULL;
	GSimpleAction* _tmp22_ = NULL;
	GSimpleAction* _tmp23_ = NULL;
	const GVariantType* _tmp24_ = NULL;
	GSimpleAction* _tmp25_ = NULL;
	GSimpleAction* _tmp26_ = NULL;
	GSimpleAction* _tmp27_ = NULL;
	GSimpleAction* _tmp28_ = NULL;
	GSimpleAction* _tmp29_ = NULL;
	GSimpleAction* _tmp30_ = NULL;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = (BoxesApp*) g_object_new (object_type, NULL);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_application_set_application_id ((GApplication*) self, "org.gnome.Boxes");
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = g_application_get_flags ((GApplication*) self);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_application_set_flags ((GApplication*) self, _tmp1_ | G_APPLICATION_HANDLES_COMMAND_LINE);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _g_object_ref0 (self);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (boxes_app_app);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_app = _tmp2_;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__g_list_free__g_object_unref0_0 (self->priv->windows);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->windows = NULL;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = g_str_hash;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = g_str_equal;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = g_hash_table_new_full (_tmp3_, _tmp4_, _g_free0_, _g_object_unref0_);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_hash_table_unref0 (self->priv->sources);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->sources = _tmp5_;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = g_str_hash;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = g_str_equal;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp8_ = g_hash_table_new_full (_tmp6_, _tmp7_, _g_free0_, _g_object_unref0_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_hash_table_unref0 (self->priv->brokers);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->brokers = _tmp8_;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp9_ = g_simple_action_new ("quit", NULL);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	action = _tmp9_;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp10_ = action;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp10_, "activate", (GCallback) ___lambda229__g_simple_action_activate, self, 0);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp11_ = action;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_action_map_add_action ((GActionMap*) self, (GAction*) _tmp11_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp12_ = g_simple_action_new ("select-all", NULL);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (action);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	action = _tmp12_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp13_ = action;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp13_, "activate", (GCallback) ___lambda230__g_simple_action_activate, self, 0);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp14_ = action;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_action_map_add_action ((GActionMap*) self, (GAction*) _tmp14_);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp15_ = g_simple_action_new ("select-running", NULL);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (action);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	action = _tmp15_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp16_ = action;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp16_, "activate", (GCallback) ___lambda231__g_simple_action_activate, self, 0);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp17_ = action;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_action_map_add_action ((GActionMap*) self, (GAction*) _tmp17_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp18_ = g_simple_action_new ("select-none", NULL);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (action);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	action = _tmp18_;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp19_ = action;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp19_, "activate", (GCallback) ___lambda232__g_simple_action_activate, self, 0);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp20_ = action;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_action_map_add_action ((GActionMap*) self, (GAction*) _tmp20_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp21_ = g_simple_action_new ("help", NULL);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (action);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	action = _tmp21_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp22_ = action;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp22_, "activate", (GCallback) ___lambda233__g_simple_action_activate, self, 0);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp23_ = action;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_action_map_add_action ((GActionMap*) self, (GAction*) _tmp23_);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp24_ = G_VARIANT_TYPE_STRING;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp25_ = g_simple_action_new ("launch-box", _tmp24_);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (action);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	action = _tmp25_;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp26_ = action;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp26_, "activate", (GCallback) ___lambda234__g_simple_action_activate, self, 0);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp27_ = action;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_action_map_add_action ((GActionMap*) self, (GAction*) _tmp27_);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp28_ = g_simple_action_new ("about", NULL);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (action);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	action = _tmp28_;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp29_ = action;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp29_, "activate", (GCallback) ___lambda235__g_simple_action_activate, self, 0);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp30_ = action;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_action_map_add_action ((GActionMap*) self, (GAction*) _tmp30_);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (action);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return self;
#line 1626 "app.c"
}


BoxesApp* boxes_app_new (void) {
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return boxes_app_construct (BOXES_TYPE_APP);
#line 1633 "app.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return _data1_;
#line 1642 "app.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 1651 "app.c"
		BoxesApp* self;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data1_->self;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (_data1_->item);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (self);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block1Data, _data1_);
#line 1661 "app.c"
	}
}


static void __lambda237_ (Block1Data* _data1_, BoxesICollectionView* view) {
	BoxesApp* self;
	BoxesICollectionView* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data1_->self;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (view != NULL);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = view;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _data1_->item;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_icollection_view_add_item (_tmp0_, _tmp1_);
#line 1680 "app.c"
}


static void ___lambda237__gfunc (gconstpointer data, gpointer self) {
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda237_ (self, (BoxesICollectionView*) data);
#line 1687 "app.c"
}


static void __lambda236_ (BoxesApp* self, BoxesCollectionItem* item) {
	Block1Data* _data1_;
	BoxesCollectionItem* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesAppWindow* _tmp2_ = NULL;
	BoxesAppWindow* _tmp3_ = NULL;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (item != NULL);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_->_ref_count_ = 1;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_->self = g_object_ref (self);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = item;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data1_->item);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_->item = _tmp1_;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = boxes_app_get_main_window (self);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = _tmp2_;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_window_foreach_view (_tmp3_, ___lambda237__gfunc, _data1_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	block1_data_unref (_data1_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_ = NULL;
#line 1723 "app.c"
}


static void ___lambda236__boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda236_ ((BoxesApp*) self, item);
#line 1730 "app.c"
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return _data2_;
#line 1739 "app.c"
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 1748 "app.c"
		BoxesApp* self;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data2_->self;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (_data2_->item);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (self);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block2Data, _data2_);
#line 1758 "app.c"
	}
}


static void __lambda239_ (Block2Data* _data2_, BoxesICollectionView* view) {
	BoxesApp* self;
	BoxesICollectionView* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data2_->self;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (view != NULL);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = view;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _data2_->item;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_icollection_view_remove_item (_tmp0_, _tmp1_);
#line 1777 "app.c"
}


static void ___lambda239__gfunc (gconstpointer data, gpointer self) {
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda239_ (self, (BoxesICollectionView*) data);
#line 1784 "app.c"
}


static void __lambda238_ (BoxesApp* self, BoxesCollectionItem* item) {
	Block2Data* _data2_;
	BoxesCollectionItem* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesAppWindow* _tmp2_ = NULL;
	BoxesAppWindow* _tmp3_ = NULL;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (item != NULL);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data2_ = g_slice_new0 (Block2Data);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data2_->_ref_count_ = 1;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data2_->self = g_object_ref (self);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = item;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data2_->item);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data2_->item = _tmp1_;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = boxes_app_get_main_window (self);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = _tmp2_;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_window_foreach_view (_tmp3_, ___lambda239__gfunc, _data2_);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	block2_data_unref (_data2_);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data2_ = NULL;
#line 1820 "app.c"
}


static void ___lambda238__boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda238_ ((BoxesApp*) self, item);
#line 1827 "app.c"
}


static void boxes_app_real_startup (GApplication* base) {
	BoxesApp * self;
	gchar** args = NULL;
	gchar** _tmp0_ = NULL;
	gint args_length1 = 0;
	gint _args_size_ = 0;
	gchar** args2 = NULL;
	gchar** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	gint args2_length1 = 0;
	gint _args2_size_ = 0;
	GMenu* menu = NULL;
	GMenu* _tmp2_ = NULL;
	GMenu* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	GMenu* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	GMenu* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	GMenu* _tmp9_ = NULL;
	BoxesCollection* _tmp10_ = NULL;
	BoxesCollection* _tmp11_ = NULL;
	BoxesCollection* _tmp12_ = NULL;
	GHashTable* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	BoxesLibvirtBroker* _tmp15_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = (BoxesApp*) base;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	G_APPLICATION_CLASS (boxes_app_parent_class)->startup ((GApplication*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_application_get_type (), GtkApplication));
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = g_new0 (gchar*, 0 + 1);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	args = _tmp0_;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	args_length1 = 0;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_args_size_ = args_length1;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = args;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1__length1 = args_length1;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	args2 = _tmp1_;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	args2_length1 = _tmp1__length1;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_args2_size_ = args2_length1;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_init (&args2_length1, &args2);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = g_menu_new ();
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	menu = _tmp2_;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = menu;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = _ ("Help");
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_menu_append (_tmp3_, _tmp4_, "app.help");
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = menu;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = _ ("About");
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_menu_append (_tmp5_, _tmp6_, "app.about");
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = menu;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp8_ = _ ("Quit");
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_menu_append (_tmp7_, _tmp8_, "app.quit");
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp9_ = menu;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_application_set_app_menu ((GtkApplication*) self, (GMenuModel*) _tmp9_);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp10_ = boxes_collection_new ();
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->collection);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self->collection = _tmp10_;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp11_ = self->collection;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp11_, "item-added", (GCallback) ___lambda236__boxes_collection_item_added, self, 0);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp12_ = self->collection;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp12_, "item-removed", (GCallback) ___lambda238__boxes_collection_item_removed, self, 0);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp13_ = self->priv->brokers;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp14_ = g_strdup ("libvirt");
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp15_ = boxes_libvirt_broker_get_default ();
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_hash_table_insert (_tmp13_, _tmp14_, (BoxesBroker*) _tmp15_);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (HAVE_OVIRT) {
#line 1931 "app.c"
		GHashTable* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		BoxesOvirtBroker* _tmp18_ = NULL;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp16_ = self->priv->brokers;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp17_ = g_strdup ("ovirt");
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp18_ = boxes_ovirt_broker_get_default ();
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_hash_table_insert (_tmp16_, _tmp17_, (BoxesBroker*) _tmp18_);
#line 1943 "app.c"
	}
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_check_cpu_vt_capability (NULL, NULL);
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_check_module_kvm_loaded (NULL, NULL);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (menu);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	args = (_vala_array_free (args, args_length1, (GDestroyNotify) g_free), NULL);
#line 1953 "app.c"
}


gboolean boxes_app_has_broker_for_source_type (BoxesApp* self, const gchar* type) {
	gboolean result = FALSE;
	GHashTable* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (type != NULL, FALSE);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->priv->brokers;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = type;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = g_hash_table_contains (_tmp0_, _tmp1_);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = _tmp2_;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 1976 "app.c"
}


static Block3Data* block3_data_ref (Block3Data* _data3_) {
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data3_->_ref_count_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return _data3_;
#line 1985 "app.c"
}


static void block3_data_unref (void * _userdata_) {
	Block3Data* _data3_;
	_data3_ = (Block3Data*) _userdata_;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data3_->_ref_count_)) {
#line 1994 "app.c"
		BoxesApp* self;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data3_->self;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		(_data3_->func_target_destroy_notify == NULL) ? NULL : (_data3_->func_target_destroy_notify (_data3_->func_target), NULL);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data3_->func = NULL;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data3_->func_target = NULL;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data3_->func_target_destroy_notify = NULL;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (self);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block3Data, _data3_);
#line 2010 "app.c"
	}
}


static void __lambda19_ (Block3Data* _data3_) {
	BoxesApp* self;
	BoxesAppCallReadyFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data3_->self;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _data3_->func;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0__target = _data3_->func_target;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ (_tmp0__target);
#line 2027 "app.c"
}


static void ___lambda19__boxes_app_ready (BoxesApp* _sender, gpointer self) {
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda19_ (self);
#line 2034 "app.c"
}


void boxes_app_call_when_ready (BoxesApp* self, BoxesAppCallReadyFunc func, void* func_target, GDestroyNotify func_target_destroy_notify) {
	Block3Data* _data3_;
	BoxesAppCallReadyFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	gboolean _tmp1_ = FALSE;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data3_ = g_slice_new0 (Block3Data);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data3_->_ref_count_ = 1;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data3_->self = g_object_ref (self);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = func;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0__target = func_target;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	(_data3_->func_target_destroy_notify == NULL) ? NULL : (_data3_->func_target_destroy_notify (_data3_->func_target), NULL);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data3_->func = NULL;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data3_->func_target = NULL;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data3_->func_target_destroy_notify = NULL;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data3_->func = _tmp0_;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data3_->func_target = _tmp0__target;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data3_->func_target_destroy_notify = func_target_destroy_notify;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = self->priv->is_ready;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp1_) {
#line 2073 "app.c"
		BoxesAppCallReadyFunc _tmp2_ = NULL;
		void* _tmp2__target = NULL;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp2_ = _data3_->func;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp2__target = _data3_->func_target;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp2_ (_tmp2__target);
#line 2082 "app.c"
	}
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_data (self, "ready", (GCallback) ___lambda19__boxes_app_ready, block3_data_ref (_data3_), (GClosureNotify) block3_data_unref, 0);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	block3_data_unref (_data3_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data3_ = NULL;
#line 2090 "app.c"
}


static void __lambda243_ (BoxesApp* self, GObject* obj, GAsyncResult* _result_) {
	GAsyncResult* _tmp0_ = NULL;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (_result_ != NULL);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _result_;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_setup_default_source_finish (self, _tmp0_);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->is_ready = TRUE;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_emit_by_name (self, "ready");
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_setup_sources (self, NULL, NULL);
#line 2108 "app.c"
}


static void ___lambda243__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda243_ ((BoxesApp*) self, source_object, res);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_unref (self);
#line 2117 "app.c"
}


static void boxes_app_real_activate (GApplication* base) {
	BoxesApp * self;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesAppWindow* window = NULL;
	BoxesAppWindow* _tmp2_ = NULL;
	BoxesAppWindow* _tmp3_ = NULL;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = (BoxesApp*) base;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	G_APPLICATION_CLASS (boxes_app_parent_class)->activate ((GApplication*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_application_get_type (), GtkApplication));
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_get_main_window (self);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp1_ != NULL) {
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return;
#line 2140 "app.c"
	}
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = boxes_app_add_new_window (self);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	window = _tmp2_;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = window;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp3_, BOXES_UI_STATE_COLLECTION);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_setup_default_source (self, ___lambda243__gasync_ready_callback, g_object_ref (self));
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (window);
#line 2154 "app.c"
}


static Block4Data* block4_data_ref (Block4Data* _data4_) {
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data4_->_ref_count_);
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return _data4_;
#line 2163 "app.c"
}


static void block4_data_unref (void * _userdata_) {
	Block4Data* _data4_;
	_data4_ = (Block4Data*) _userdata_;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data4_->_ref_count_)) {
#line 2172 "app.c"
		BoxesApp* self;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data4_->self;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (_data4_->app);
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (self);
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block4Data, _data4_);
#line 2182 "app.c"
	}
}


static Block5Data* block5_data_ref (Block5Data* _data5_) {
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data5_->_ref_count_);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return _data5_;
#line 2192 "app.c"
}


static void block5_data_unref (void * _userdata_) {
	Block5Data* _data5_;
	_data5_ = (Block5Data*) _userdata_;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data5_->_ref_count_)) {
#line 2201 "app.c"
		BoxesApp* self;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data5_->_data4_->self;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_data5_->uuid);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		block4_data_unref (_data5_->_data4_);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data5_->_data4_ = NULL;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block5Data, _data5_);
#line 2213 "app.c"
	}
}


static void ___lambda245_ (Block5Data* _data5_) {
	Block4Data* _data4_;
	BoxesApp* self;
	BoxesApp* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data4_ = _data5_->_data4_;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data4_->self;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _data4_->app;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _data5_->uuid;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_open_uuid (_tmp0_, _tmp1_);
#line 2233 "app.c"
}


static void ____lambda245__boxes_app_call_ready_func (gpointer self) {
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	___lambda245_ (self);
#line 2240 "app.c"
}


static Block6Data* block6_data_ref (Block6Data* _data6_) {
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data6_->_ref_count_);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return _data6_;
#line 2249 "app.c"
}


static void block6_data_unref (void * _userdata_) {
	Block6Data* _data6_;
	_data6_ = (Block6Data*) _userdata_;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data6_->_ref_count_)) {
#line 2258 "app.c"
		BoxesApp* self;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data6_->_data4_->self;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_data6_->arg);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		block4_data_unref (_data6_->_data4_);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data6_->_data4_ = NULL;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block6Data, _data6_);
#line 2270 "app.c"
	}
}


static void ____lambda246_ (Block6Data* _data6_) {
	Block4Data* _data4_;
	BoxesApp* self;
	GFile* file = NULL;
	const gchar* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	gboolean is_uri = FALSE;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	GFile* _tmp6_ = NULL;
	gboolean _tmp7_ = FALSE;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data4_ = _data6_->_data4_;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data4_->self;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _data6_->arg;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = g_file_new_for_commandline_arg (_tmp0_);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	file = _tmp1_;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _data6_->arg;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = g_uri_parse_scheme (_tmp2_);
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = _tmp3_;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = _tmp4_ != NULL;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (_tmp4_);
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	is_uri = _tmp5_;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = file;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = g_file_query_exists (_tmp6_, NULL);
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp7_) {
#line 2316 "app.c"
		gboolean _tmp8_ = FALSE;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp8_ = is_uri;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (_tmp8_) {
#line 2322 "app.c"
			BoxesAppWindow* _tmp9_ = NULL;
			BoxesAppWindow* _tmp10_ = NULL;
			BoxesWizardWindow* _tmp11_ = NULL;
			BoxesWizard* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp9_ = boxes_app_get_main_window (self);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp10_ = _tmp9_;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp11_ = _tmp10_->wizard_window;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp12_ = _tmp11_->wizard;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp13_ = _data6_->arg;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_wizard_open_with_uri (_tmp12_, _tmp13_, TRUE);
#line 2340 "app.c"
		} else {
			BoxesAppWindow* _tmp14_ = NULL;
			BoxesAppWindow* _tmp15_ = NULL;
			BoxesWizardWindow* _tmp16_ = NULL;
			BoxesWizard* _tmp17_ = NULL;
			GFile* _tmp18_ = NULL;
			gchar* _tmp19_ = NULL;
			gchar* _tmp20_ = NULL;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp14_ = boxes_app_get_main_window (self);
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp15_ = _tmp14_;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp16_ = _tmp15_->wizard_window;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp17_ = _tmp16_->wizard;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp18_ = file;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp19_ = g_file_get_uri (_tmp18_);
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp20_ = _tmp19_;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_wizard_open_with_uri (_tmp17_, _tmp20_, TRUE);
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_g_free0 (_tmp20_);
#line 2367 "app.c"
		}
	} else {
		gboolean _tmp21_ = FALSE;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp21_ = is_uri;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (_tmp21_) {
#line 2375 "app.c"
			BoxesAppWindow* _tmp22_ = NULL;
			BoxesAppWindow* _tmp23_ = NULL;
			BoxesWizardWindow* _tmp24_ = NULL;
			BoxesWizard* _tmp25_ = NULL;
			const gchar* _tmp26_ = NULL;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp22_ = boxes_app_get_main_window (self);
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp23_ = _tmp22_;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp24_ = _tmp23_->wizard_window;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp25_ = _tmp24_->wizard;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp26_ = _data6_->arg;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_wizard_open_with_uri (_tmp25_, _tmp26_, TRUE);
#line 2393 "app.c"
		} else {
			const gchar* _tmp27_ = NULL;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp27_ = _data6_->arg;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_app_open_name (self, _tmp27_);
#line 2400 "app.c"
		}
	}
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (file);
#line 2405 "app.c"
}


static void _____lambda246__boxes_app_call_ready_func (gpointer self) {
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	____lambda246_ (self);
#line 2412 "app.c"
}


static gchar* _vala_g_strjoinv (const gchar* separator, gchar** str_array, int str_array_length1) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	gchar** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
#line 964 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	_tmp0_ = separator;
#line 964 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	if (_tmp0_ == NULL) {
#line 965 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		separator = "";
#line 2429 "app.c"
	}
#line 967 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	_tmp3_ = str_array;
#line 967 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	_tmp3__length1 = str_array_length1;
#line 967 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	if (_tmp3_ != NULL) {
#line 967 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp2_ = TRUE;
#line 2439 "app.c"
	} else {
		gchar** _tmp4_ = NULL;
		gint _tmp4__length1 = 0;
#line 967 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp4_ = str_array;
#line 967 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp4__length1 = str_array_length1;
#line 967 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp2_ = _tmp4__length1 > 0;
#line 2449 "app.c"
	}
#line 967 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	if (_tmp2_) {
#line 967 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp1_ = TRUE;
#line 2455 "app.c"
	} else {
		gboolean _tmp5_ = FALSE;
		gchar** _tmp6_ = NULL;
		gint _tmp6__length1 = 0;
#line 967 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp6_ = str_array;
#line 967 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp6__length1 = str_array_length1;
#line 967 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		if (_tmp6__length1 == -1) {
#line 2466 "app.c"
			gchar** _tmp7_ = NULL;
			gint _tmp7__length1 = 0;
			const gchar* _tmp8_ = NULL;
#line 967 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
			_tmp7_ = str_array;
#line 967 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
			_tmp7__length1 = str_array_length1;
#line 967 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
			_tmp8_ = _tmp7_[0];
#line 967 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
			_tmp5_ = _tmp8_ != NULL;
#line 2478 "app.c"
		} else {
#line 967 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
			_tmp5_ = FALSE;
#line 2482 "app.c"
		}
#line 967 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp1_ = _tmp5_;
#line 2486 "app.c"
	}
#line 967 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	if (_tmp1_) {
#line 2490 "app.c"
		gint i = 0;
		gsize len = 0UL;
		gint _tmp31_ = 0;
		gint _tmp33_ = 0;
		gint _tmp34_ = 0;
		gsize _tmp35_ = 0UL;
		const gchar* _tmp36_ = NULL;
		gint _tmp37_ = 0;
		gint _tmp38_ = 0;
		gint _tmp39_ = 0;
		const gchar* res = NULL;
		gsize _tmp40_ = 0UL;
		void* _tmp41_ = NULL;
		void* ptr = NULL;
		const gchar* _tmp42_ = NULL;
		gchar** _tmp43_ = NULL;
		gint _tmp43__length1 = 0;
		const gchar* _tmp44_ = NULL;
		void* _tmp45_ = NULL;
		const gchar* _tmp62_ = NULL;
#line 969 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		len = (gsize) 1;
#line 2513 "app.c"
		{
			gboolean _tmp9_ = FALSE;
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
			i = 0;
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
			_tmp9_ = TRUE;
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 2522 "app.c"
				gboolean _tmp11_ = FALSE;
				gboolean _tmp12_ = FALSE;
				gchar** _tmp13_ = NULL;
				gint _tmp13__length1 = 0;
				gint _tmp21_ = 0;
				gchar** _tmp22_ = NULL;
				gint _tmp22__length1 = 0;
				gint _tmp23_ = 0;
				const gchar* _tmp24_ = NULL;
				gsize _tmp30_ = 0UL;
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				if (!_tmp9_) {
#line 2535 "app.c"
					gint _tmp10_ = 0;
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp10_ = i;
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					i = _tmp10_ + 1;
#line 2541 "app.c"
				}
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp9_ = FALSE;
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp13_ = str_array;
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp13__length1 = str_array_length1;
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				if (_tmp13__length1 != -1) {
#line 2551 "app.c"
					gint _tmp14_ = 0;
					gchar** _tmp15_ = NULL;
					gint _tmp15__length1 = 0;
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp14_ = i;
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp15_ = str_array;
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp15__length1 = str_array_length1;
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp12_ = _tmp14_ < _tmp15__length1;
#line 2563 "app.c"
				} else {
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp12_ = FALSE;
#line 2567 "app.c"
				}
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				if (_tmp12_) {
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp11_ = TRUE;
#line 2573 "app.c"
				} else {
					gboolean _tmp16_ = FALSE;
					gchar** _tmp17_ = NULL;
					gint _tmp17__length1 = 0;
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp17_ = str_array;
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp17__length1 = str_array_length1;
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					if (_tmp17__length1 == -1) {
#line 2584 "app.c"
						gchar** _tmp18_ = NULL;
						gint _tmp18__length1 = 0;
						gint _tmp19_ = 0;
						const gchar* _tmp20_ = NULL;
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
						_tmp18_ = str_array;
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
						_tmp18__length1 = str_array_length1;
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
						_tmp19_ = i;
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
						_tmp20_ = _tmp18_[_tmp19_];
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
						_tmp16_ = _tmp20_ != NULL;
#line 2599 "app.c"
					} else {
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
						_tmp16_ = FALSE;
#line 2603 "app.c"
					}
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp11_ = _tmp16_;
#line 2607 "app.c"
				}
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				if (!_tmp11_) {
#line 970 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					break;
#line 2613 "app.c"
				}
#line 971 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp22_ = str_array;
#line 971 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp22__length1 = str_array_length1;
#line 971 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp23_ = i;
#line 971 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp24_ = _tmp22_[_tmp23_];
#line 971 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				if (_tmp24_ != NULL) {
#line 2625 "app.c"
					gchar** _tmp25_ = NULL;
					gint _tmp25__length1 = 0;
					gint _tmp26_ = 0;
					const gchar* _tmp27_ = NULL;
					gint _tmp28_ = 0;
					gint _tmp29_ = 0;
#line 971 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp25_ = str_array;
#line 971 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp25__length1 = str_array_length1;
#line 971 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp26_ = i;
#line 971 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp27_ = _tmp25_[_tmp26_];
#line 971 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp28_ = strlen ((const gchar*) _tmp27_);
#line 971 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp29_ = _tmp28_;
#line 971 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp21_ = _tmp29_;
#line 2646 "app.c"
				} else {
#line 971 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp21_ = 0;
#line 2650 "app.c"
				}
#line 971 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp30_ = len;
#line 971 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				len = _tmp30_ + _tmp21_;
#line 2656 "app.c"
			}
		}
#line 973 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp31_ = i;
#line 973 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		if (_tmp31_ == 0) {
#line 2663 "app.c"
			gchar* _tmp32_ = NULL;
#line 974 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
			_tmp32_ = g_strdup ("");
#line 974 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
			result = _tmp32_;
#line 974 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
			return result;
#line 2671 "app.c"
		}
#line 976 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp33_ = i;
#line 976 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		str_array_length1 = _tmp33_;
#line 976 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp34_ = str_array_length1;
#line 977 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp35_ = len;
#line 977 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp36_ = separator;
#line 977 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp37_ = strlen ((const gchar*) _tmp36_);
#line 977 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp38_ = _tmp37_;
#line 977 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp39_ = i;
#line 977 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		len = _tmp35_ + (_tmp38_ * (_tmp39_ - 1));
#line 979 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp40_ = len;
#line 979 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp41_ = g_malloc (_tmp40_);
#line 979 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		res = _tmp41_;
#line 980 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp42_ = res;
#line 980 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp43_ = str_array;
#line 980 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp43__length1 = str_array_length1;
#line 980 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp44_ = _tmp43_[0];
#line 980 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp45_ = g_stpcpy ((void*) _tmp42_, (const gchar*) _tmp44_);
#line 980 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		ptr = _tmp45_;
#line 2709 "app.c"
		{
			gboolean _tmp46_ = FALSE;
#line 981 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
			i = 1;
#line 981 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
			_tmp46_ = TRUE;
#line 981 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 2718 "app.c"
				gint _tmp48_ = 0;
				gchar** _tmp49_ = NULL;
				gint _tmp49__length1 = 0;
				void* _tmp50_ = NULL;
				const gchar* _tmp51_ = NULL;
				void* _tmp52_ = NULL;
				const gchar* _tmp53_ = NULL;
				gchar** _tmp54_ = NULL;
				gint _tmp54__length1 = 0;
				gint _tmp55_ = 0;
				const gchar* _tmp56_ = NULL;
				void* _tmp60_ = NULL;
				void* _tmp61_ = NULL;
#line 981 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				if (!_tmp46_) {
#line 2734 "app.c"
					gint _tmp47_ = 0;
#line 981 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp47_ = i;
#line 981 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					i = _tmp47_ + 1;
#line 2740 "app.c"
				}
#line 981 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp46_ = FALSE;
#line 981 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp48_ = i;
#line 981 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp49_ = str_array;
#line 981 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp49__length1 = str_array_length1;
#line 981 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				if (!(_tmp48_ < _tmp49__length1)) {
#line 981 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					break;
#line 2754 "app.c"
				}
#line 982 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp50_ = ptr;
#line 982 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp51_ = separator;
#line 982 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp52_ = g_stpcpy (_tmp50_, (const gchar*) _tmp51_);
#line 982 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				ptr = _tmp52_;
#line 983 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp54_ = str_array;
#line 983 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp54__length1 = str_array_length1;
#line 983 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp55_ = i;
#line 983 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp56_ = _tmp54_[_tmp55_];
#line 983 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				if (_tmp56_ != NULL) {
#line 2774 "app.c"
					gchar** _tmp57_ = NULL;
					gint _tmp57__length1 = 0;
					gint _tmp58_ = 0;
					const gchar* _tmp59_ = NULL;
#line 983 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp57_ = str_array;
#line 983 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp57__length1 = str_array_length1;
#line 983 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp58_ = i;
#line 983 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp59_ = _tmp57_[_tmp58_];
#line 983 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp53_ = (const gchar*) _tmp59_;
#line 2789 "app.c"
				} else {
#line 983 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
					_tmp53_ = "";
#line 2793 "app.c"
				}
#line 983 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp60_ = ptr;
#line 983 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				_tmp61_ = g_stpcpy (_tmp60_, _tmp53_);
#line 983 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
				ptr = _tmp61_;
#line 2801 "app.c"
			}
		}
#line 986 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp62_ = res;
#line 986 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		res = NULL;
#line 986 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		result = (gchar*) _tmp62_;
#line 986 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		return result;
#line 2812 "app.c"
	} else {
		gchar* _tmp63_ = NULL;
#line 988 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_tmp63_ = g_strdup ("");
#line 988 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		result = _tmp63_;
#line 988 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		return result;
#line 2821 "app.c"
	}
}


static void ___lambda247_ (BoxesApp* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesSearchbar* _tmp2_ = NULL;
	gchar** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	BoxesAppWindow* _tmp6_ = NULL;
	BoxesAppWindow* _tmp7_ = NULL;
	BoxesUIState _tmp8_ = 0;
	BoxesUIState _tmp9_ = 0;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_get_main_window (self);
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _tmp1_->searchbar;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = boxes_app_opt_search;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3__length1 = boxes_app_opt_search_length1;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = _vala_g_strjoinv (" ", _tmp3_, _tmp3__length1);
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = _tmp4_;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_searchbar_set_text (_tmp2_, _tmp5_);
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (_tmp5_);
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = boxes_app_get_main_window (self);
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = _tmp6_;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp8_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp7_);
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp9_ = _tmp8_;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp9_ == BOXES_UI_STATE_COLLECTION) {
#line 2866 "app.c"
		BoxesAppWindow* _tmp10_ = NULL;
		BoxesAppWindow* _tmp11_ = NULL;
		BoxesSearchbar* _tmp12_ = NULL;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp10_ = boxes_app_get_main_window (self);
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp11_ = _tmp10_;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp12_ = _tmp11_->searchbar;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_object_set ((GtkSearchBar*) _tmp12_, "search-mode-enabled", TRUE, NULL);
#line 2878 "app.c"
	}
}


static void ____lambda247__boxes_app_call_ready_func (gpointer self) {
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	___lambda247_ ((BoxesApp*) self);
#line 2886 "app.c"
}


static gint boxes_app_real_command_line (GApplication* base, GApplicationCommandLine* cmdline) {
	BoxesApp * self;
	gint result = 0;
	Block4Data* _data4_;
	gchar* parameter_string = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	GOptionContext* opt_context = NULL;
	const gchar* _tmp2_ = NULL;
	GOptionContext* _tmp3_ = NULL;
	GOptionContext* _tmp4_ = NULL;
	GOptionContext* _tmp5_ = NULL;
	gboolean _tmp18_ = FALSE;
	gboolean _tmp23_ = FALSE;
	gchar** _tmp24_ = NULL;
	gint _tmp24__length1 = 0;
	BoxesApp* _tmp34_ = NULL;
	const gchar* _tmp35_ = NULL;
	gchar** _tmp42_ = NULL;
	gint _tmp42__length1 = 0;
	gboolean _tmp43_ = FALSE;
	GError * _inner_error_ = NULL;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = (BoxesApp*) base;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (cmdline != NULL, 0);
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data4_ = g_slice_new0 (Block4Data);
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data4_->_ref_count_ = 1;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data4_->self = g_object_ref (self);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_fullscreen = FALSE;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_help = FALSE;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (boxes_app_opt_open_uuid);
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_open_uuid = NULL;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_uris = (_vala_array_free (boxes_app_opt_uris, boxes_app_opt_uris_length1, (GDestroyNotify) g_free), NULL);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_uris = NULL;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_uris_length1 = 0;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_boxes_app_opt_uris_size_ = boxes_app_opt_uris_length1;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_search = (_vala_array_free (boxes_app_opt_search, boxes_app_opt_search_length1, (GDestroyNotify) g_free), NULL);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_search = NULL;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_search_length1 = 0;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_boxes_app_opt_search_size_ = boxes_app_opt_search_length1;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _ ("- A simple application to access remote or virtual machines");
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	parameter_string = _tmp1_;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = parameter_string;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = g_option_context_new (_tmp2_);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	opt_context = _tmp3_;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = opt_context;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_option_context_add_main_entries (_tmp4_, BOXES_APP_options, NULL);
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = opt_context;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_option_context_set_help_enabled (_tmp5_, FALSE);
#line 2966 "app.c"
	{
		gchar** args1 = NULL;
		GApplicationCommandLine* _tmp6_ = NULL;
		gint _tmp7_ = 0;
		gchar** _tmp8_ = NULL;
		gint args1_length1 = 0;
		gint _args1_size_ = 0;
		gchar** args2 = NULL;
		gchar** _tmp9_ = NULL;
		gint _tmp9__length1 = 0;
		gint args2_length1 = 0;
		gint _args2_size_ = 0;
		GOptionContext* _tmp10_ = NULL;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp6_ = cmdline;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp8_ = g_application_command_line_get_arguments (_tmp6_, &_tmp7_);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		args1 = _tmp8_;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		args1_length1 = _tmp7_;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_args1_size_ = args1_length1;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp9_ = args1;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp9__length1 = args1_length1;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		args2 = _tmp9_;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		args2_length1 = _tmp9__length1;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_args2_size_ = args2_length1;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp10_ = opt_context;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_option_context_parse (_tmp10_, &args2_length1, &args2, &_inner_error_);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			args1 = (_vala_array_free (args1, args1_length1, (GDestroyNotify) g_free), NULL);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			if (_inner_error_->domain == G_OPTION_ERROR) {
#line 3010 "app.c"
				goto __catch1_g_option_error;
			}
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			args1 = (_vala_array_free (args1, args1_length1, (GDestroyNotify) g_free), NULL);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_g_option_context_free0 (opt_context);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_g_free0 (parameter_string);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			block4_data_unref (_data4_);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data4_ = NULL;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			g_clear_error (&_inner_error_);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			return 0;
#line 3029 "app.c"
		}
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		args1 = (_vala_array_free (args1, args1_length1, (GDestroyNotify) g_free), NULL);
#line 3033 "app.c"
	}
	goto __finally1;
	__catch1_g_option_error:
	{
		GError* _error_ = NULL;
		GApplicationCommandLine* _tmp11_ = NULL;
		GError* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		GApplicationCommandLine* _tmp14_ = NULL;
		GOptionContext* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_error_ = _inner_error_;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_inner_error_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp11_ = cmdline;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp12_ = _error_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp13_ = _tmp12_->message;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_application_command_line_printerr (_tmp11_, "%s\n", _tmp13_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp14_ = cmdline;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp15_ = opt_context;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp16_ = g_option_context_get_help (_tmp15_, TRUE, NULL);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp17_ = _tmp16_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_application_command_line_printerr (_tmp14_, "%s", _tmp17_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_tmp17_);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		result = 1;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_error_free0 (_error_);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_option_context_free0 (opt_context);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (parameter_string);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		block4_data_unref (_data4_);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data4_ = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return result;
#line 3084 "app.c"
	}
	__finally1:
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_option_context_free0 (opt_context);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (parameter_string);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		block4_data_unref (_data4_);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data4_ = NULL;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_clear_error (&_inner_error_);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return 0;
#line 3103 "app.c"
	}
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp18_ = boxes_app_opt_help;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp18_) {
#line 3109 "app.c"
		GApplicationCommandLine* _tmp19_ = NULL;
		GOptionContext* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp19_ = cmdline;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp20_ = opt_context;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp21_ = g_option_context_get_help (_tmp20_, TRUE, NULL);
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp22_ = _tmp21_;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_application_command_line_printerr (_tmp19_, "%s", _tmp22_);
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_tmp22_);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		result = 1;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_option_context_free0 (opt_context);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (parameter_string);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		block4_data_unref (_data4_);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data4_ = NULL;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return result;
#line 3138 "app.c"
	}
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp24_ = boxes_app_opt_uris;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp24__length1 = boxes_app_opt_uris_length1;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp24__length1 > 1) {
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp23_ = TRUE;
#line 3148 "app.c"
	} else {
		gboolean _tmp25_ = FALSE;
		const gchar* _tmp26_ = NULL;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp26_ = boxes_app_opt_open_uuid;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (_tmp26_ != NULL) {
#line 3156 "app.c"
			gchar** _tmp27_ = NULL;
			gint _tmp27__length1 = 0;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp27_ = boxes_app_opt_uris;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp27__length1 = boxes_app_opt_uris_length1;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp25_ = _tmp27_ != NULL;
#line 3165 "app.c"
		} else {
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp25_ = FALSE;
#line 3169 "app.c"
		}
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp23_ = _tmp25_;
#line 3173 "app.c"
	}
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp23_) {
#line 3177 "app.c"
		GApplicationCommandLine* _tmp28_ = NULL;
		const gchar* _tmp29_ = NULL;
		GApplicationCommandLine* _tmp30_ = NULL;
		GOptionContext* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp28_ = cmdline;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp29_ = _ ("Too many command line arguments specified.\n");
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_application_command_line_printerr (_tmp28_, "%s", _tmp29_);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp30_ = cmdline;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp31_ = opt_context;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp32_ = g_option_context_get_help (_tmp31_, TRUE, NULL);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp33_ = _tmp32_;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_application_command_line_printerr (_tmp30_, "%s", _tmp33_);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_tmp33_);
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		result = 1;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_option_context_free0 (opt_context);
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (parameter_string);
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		block4_data_unref (_data4_);
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data4_ = NULL;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return result;
#line 3214 "app.c"
	}
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_application_activate ((GApplication*) self);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp34_ = _g_object_ref0 (self);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data4_->app = _tmp34_;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp35_ = boxes_app_opt_open_uuid;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp35_ != NULL) {
#line 3226 "app.c"
		Block5Data* _data5_;
		const gchar* _tmp36_ = NULL;
		gchar* _tmp37_ = NULL;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data5_ = g_slice_new0 (Block5Data);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data5_->_ref_count_ = 1;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data5_->_data4_ = block4_data_ref (_data4_);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp36_ = boxes_app_opt_open_uuid;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp37_ = g_strdup (_tmp36_);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data5_->uuid = _tmp37_;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_app_call_when_ready (self, ____lambda245__boxes_app_call_ready_func, block5_data_ref (_data5_), block5_data_unref);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		block5_data_unref (_data5_);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data5_ = NULL;
#line 3248 "app.c"
	} else {
		gchar** _tmp38_ = NULL;
		gint _tmp38__length1 = 0;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp38_ = boxes_app_opt_uris;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp38__length1 = boxes_app_opt_uris_length1;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (_tmp38_ != NULL) {
#line 3258 "app.c"
			Block6Data* _data6_;
			gchar** _tmp39_ = NULL;
			gint _tmp39__length1 = 0;
			const gchar* _tmp40_ = NULL;
			gchar* _tmp41_ = NULL;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data6_ = g_slice_new0 (Block6Data);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data6_->_ref_count_ = 1;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data6_->_data4_ = block4_data_ref (_data4_);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp39_ = boxes_app_opt_uris;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp39__length1 = boxes_app_opt_uris_length1;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp40_ = _tmp39_[0];
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp41_ = g_strdup (_tmp40_);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data6_->arg = _tmp41_;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_app_call_when_ready (self, _____lambda246__boxes_app_call_ready_func, block6_data_ref (_data6_), block6_data_unref);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			block6_data_unref (_data6_);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data6_ = NULL;
#line 3286 "app.c"
		}
	}
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp42_ = boxes_app_opt_search;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp42__length1 = boxes_app_opt_search_length1;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp42_ != NULL) {
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_app_call_when_ready (self, ____lambda247__boxes_app_call_ready_func, g_object_ref (self), g_object_unref);
#line 3297 "app.c"
	}
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp43_ = boxes_app_opt_fullscreen;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp43_) {
#line 3303 "app.c"
		BoxesAppWindow* _tmp44_ = NULL;
		BoxesAppWindow* _tmp45_ = NULL;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp44_ = boxes_app_get_main_window (self);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp45_ = _tmp44_;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_app_window_set_fullscreened (_tmp45_, TRUE);
#line 3312 "app.c"
	}
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = 0;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_option_context_free0 (opt_context);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (parameter_string);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	block4_data_unref (_data4_);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data4_ = NULL;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 3326 "app.c"
}


static gboolean __lambda25_ (BoxesApp* self) {
	gboolean result = FALSE;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_application_quit ((GApplication*) self);
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = FALSE;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 3338 "app.c"
}


static gboolean ___lambda25__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda25_ ((BoxesApp*) self);
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 3347 "app.c"
}


gboolean boxes_app_quit_app (BoxesApp* self) {
	gboolean result = FALSE;
	GList* _tmp0_ = NULL;
	GdkDisplay* display = NULL;
	GdkDisplay* _tmp3_ = NULL;
	GdkDisplay* _tmp4_ = NULL;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->priv->windows;
#line 3361 "app.c"
	{
		GList* window_collection = NULL;
		GList* window_it = NULL;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		window_collection = _tmp0_;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		for (window_it = window_collection; window_it != NULL; window_it = window_it->next) {
#line 3369 "app.c"
			BoxesAppWindow* _tmp1_ = NULL;
			BoxesAppWindow* window = NULL;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp1_ = _g_object_ref0 ((BoxesAppWindow*) window_it->data);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			window = _tmp1_;
#line 3376 "app.c"
			{
				BoxesAppWindow* _tmp2_ = NULL;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp2_ = window;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				gtk_widget_hide ((GtkWidget*) _tmp2_);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (window);
#line 3385 "app.c"
			}
		}
	}
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = gdk_display_get_default ();
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	display = _tmp4_;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	gdk_display_flush (display);
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda25__gsource_func, g_object_ref (self), g_object_unref);
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = TRUE;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (display);
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 3405 "app.c"
}


static void boxes_app_real_shutdown (GApplication* base) {
	BoxesApp * self;
	GList* _tmp0_ = NULL;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = (BoxesApp*) base;
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	G_APPLICATION_CLASS (boxes_app_parent_class)->shutdown ((GApplication*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_application_get_type (), GtkApplication));
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->priv->windows;
#line 3418 "app.c"
	{
		GList* window_collection = NULL;
		GList* window_it = NULL;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		window_collection = _tmp0_;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		for (window_it = window_collection; window_it != NULL; window_it = window_it->next) {
#line 3426 "app.c"
			BoxesAppWindow* _tmp1_ = NULL;
			BoxesAppWindow* window = NULL;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp1_ = _g_object_ref0 ((BoxesAppWindow*) window_it->data);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			window = _tmp1_;
#line 3433 "app.c"
			{
				BoxesAppWindow* _tmp2_ = NULL;
				BoxesNotificationbar* _tmp3_ = NULL;
				BoxesNotificationbar* _tmp4_ = NULL;
				BoxesAppWindow* _tmp5_ = NULL;
				BoxesWizardWindow* _tmp6_ = NULL;
				BoxesWizard* _tmp7_ = NULL;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp2_ = window;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp3_ = boxes_app_window_get_notificationbar (_tmp2_);
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp4_ = _tmp3_;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_notificationbar_cancel (_tmp4_);
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp5_ = window;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp6_ = _tmp5_->wizard_window;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp7_ = _tmp6_->wizard;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_wizard_cleanup (_tmp7_);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (window);
#line 3459 "app.c"
			}
		}
	}
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_suspend_machines (self);
#line 3465 "app.c"
}


void boxes_app_open_name (BoxesApp* self, const gchar* name) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesCollection* _tmp2_ = NULL;
	GPtrArray* _tmp3_ = NULL;
	gpointer* _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (name != NULL);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_get_main_window (self);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp1_, BOXES_UI_STATE_COLLECTION);
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = self->collection;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = _tmp2_->items;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = _tmp3_->pdata;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4__length1 = (gint) _tmp3_->len;
#line 3494 "app.c"
	{
		BoxesCollectionItem** item_collection = NULL;
		gint item_collection_length1 = 0;
		gint _item_collection_size_ = 0;
		gint item_it = 0;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection = _tmp4_;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection_length1 = _tmp4__length1;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		for (item_it = 0; item_it < _tmp4__length1; item_it = item_it + 1) {
#line 3506 "app.c"
			BoxesCollectionItem* _tmp5_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp5_ = _g_object_ref0 (item_collection[item_it]);
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			item = _tmp5_;
#line 3513 "app.c"
			{
				BoxesCollectionItem* _tmp6_ = NULL;
				const gchar* _tmp7_ = NULL;
				const gchar* _tmp8_ = NULL;
				const gchar* _tmp9_ = NULL;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp6_ = item;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp7_ = boxes_collection_item_get_name (_tmp6_);
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp8_ = _tmp7_;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp9_ = name;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				if (g_strcmp0 (_tmp8_, _tmp9_) == 0) {
#line 3529 "app.c"
					BoxesAppWindow* _tmp10_ = NULL;
					BoxesAppWindow* _tmp11_ = NULL;
					BoxesCollectionItem* _tmp12_ = NULL;
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp10_ = boxes_app_get_main_window (self);
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp11_ = _tmp10_;
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp12_ = item;
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					boxes_app_window_select_item (_tmp11_, _tmp12_);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_g_object_unref0 (item);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					break;
#line 3545 "app.c"
				}
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (item);
#line 3549 "app.c"
			}
		}
	}
}


gboolean boxes_app_open_uuid (BoxesApp* self, const gchar* uuid) {
	gboolean result = FALSE;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesCollection* _tmp2_ = NULL;
	GPtrArray* _tmp3_ = NULL;
	gpointer* _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (uuid != NULL, FALSE);
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_get_main_window (self);
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp1_, BOXES_UI_STATE_COLLECTION);
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = self->collection;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = _tmp2_->items;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = _tmp3_->pdata;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4__length1 = (gint) _tmp3_->len;
#line 3582 "app.c"
	{
		BoxesCollectionItem** item_collection = NULL;
		gint item_collection_length1 = 0;
		gint _item_collection_size_ = 0;
		gint item_it = 0;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection = _tmp4_;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection_length1 = _tmp4__length1;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		for (item_it = 0; item_it < _tmp4__length1; item_it = item_it + 1) {
#line 3594 "app.c"
			BoxesCollectionItem* _tmp5_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp5_ = _g_object_ref0 (item_collection[item_it]);
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			item = _tmp5_;
#line 3601 "app.c"
			{
				BoxesCollectionItem* _tmp6_ = NULL;
				BoxesMachine* machine = NULL;
				BoxesCollectionItem* _tmp7_ = NULL;
				BoxesMachine* _tmp8_ = NULL;
				BoxesMachine* _tmp9_ = NULL;
				BoxesBoxConfig* _tmp10_ = NULL;
				gchar* _tmp11_ = NULL;
				gchar* _tmp12_ = NULL;
				gchar* _tmp13_ = NULL;
				const gchar* _tmp14_ = NULL;
				gboolean _tmp15_ = FALSE;
				BoxesAppWindow* _tmp16_ = NULL;
				BoxesAppWindow* _tmp17_ = NULL;
				BoxesCollectionItem* _tmp18_ = NULL;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp6_ = item;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, BOXES_TYPE_MACHINE)) {
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_g_object_unref0 (item);
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					continue;
#line 3625 "app.c"
				}
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp7_ = item;
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp7_) : NULL);
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				machine = _tmp8_;
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp9_ = machine;
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp10_ = _tmp9_->config;
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp11_ = boxes_box_config_get_uuid (_tmp10_);
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp12_ = _tmp11_;
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp13_ = _tmp12_;
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp14_ = uuid;
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp15_ = g_strcmp0 (_tmp13_, _tmp14_) != 0;
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_free0 (_tmp13_);
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				if (_tmp15_) {
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_g_object_unref0 (machine);
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_g_object_unref0 (item);
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					continue;
#line 3657 "app.c"
				}
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp16_ = boxes_app_get_main_window (self);
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp17_ = _tmp16_;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp18_ = item;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_app_window_select_item (_tmp17_, _tmp18_);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				result = TRUE;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (machine);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (item);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				return result;
#line 3675 "app.c"
			}
		}
	}
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = FALSE;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 3683 "app.c"
}


void boxes_app_open_selected_items_in_new_window (BoxesApp* self) {
	GList* selected_items = NULL;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesICollectionView* _tmp2_ = NULL;
	BoxesICollectionView* _tmp3_ = NULL;
	GList* _tmp4_ = NULL;
	BoxesAppWindow* _tmp5_ = NULL;
	BoxesAppWindow* _tmp6_ = NULL;
	GList* _tmp7_ = NULL;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_get_main_window (self);
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = boxes_app_window_get_view (_tmp1_);
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = _tmp2_;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = boxes_icollection_view_get_selected_items (_tmp3_);
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	selected_items = _tmp4_;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = boxes_app_get_main_window (self);
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = _tmp5_;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_window_set_selection_mode (_tmp6_, FALSE);
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = selected_items;
#line 3719 "app.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection = _tmp7_;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 3727 "app.c"
			BoxesCollectionItem* _tmp8_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp8_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			item = _tmp8_;
#line 3734 "app.c"
			{
				BoxesCollectionItem* _tmp9_ = NULL;
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp9_ = item;
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, BOXES_TYPE_MACHINE)) {
#line 3741 "app.c"
					BoxesCollectionItem* _tmp10_ = NULL;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp10_ = item;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					boxes_app_open_in_new_window (self, G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp10_) : NULL);
#line 3747 "app.c"
				}
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (item);
#line 3751 "app.c"
			}
		}
	}
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__g_list_free__g_object_unref0_0 (selected_items);
#line 3757 "app.c"
}


void boxes_app_open_in_new_window (BoxesApp* self, BoxesMachine* machine) {
	BoxesMachine* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesAppWindow* _tmp2_ = NULL;
	BoxesAppWindow* _tmp3_ = NULL;
	BoxesAppWindow* _tmp4_ = NULL;
	BoxesMachine* _tmp8_ = NULL;
	BoxesUIState _tmp9_ = 0;
	BoxesUIState _tmp10_ = 0;
	BoxesAppWindow* window = NULL;
	BoxesAppWindow* _tmp14_ = NULL;
	BoxesAppWindow* _tmp15_ = NULL;
	BoxesMachine* _tmp16_ = NULL;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (machine != NULL);
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = machine;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = boxes_machine_get_window (_tmp0_);
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _tmp1_;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = boxes_app_get_main_window (self);
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = _tmp3_;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp2_ != _tmp4_) {
#line 3790 "app.c"
		BoxesMachine* _tmp5_ = NULL;
		BoxesAppWindow* _tmp6_ = NULL;
		BoxesAppWindow* _tmp7_ = NULL;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp5_ = machine;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp6_ = boxes_machine_get_window (_tmp5_);
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp7_ = _tmp6_;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		gtk_window_present ((GtkWindow*) _tmp7_);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return;
#line 3804 "app.c"
	}
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp8_ = machine;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp9_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp8_);
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp10_ = _tmp9_;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp10_ == BOXES_UI_STATE_DISPLAY) {
#line 3814 "app.c"
		BoxesMachine* _tmp11_ = NULL;
		BoxesAppWindow* _tmp12_ = NULL;
		BoxesAppWindow* _tmp13_ = NULL;
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp11_ = machine;
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp12_ = boxes_machine_get_window (_tmp11_);
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp13_ = _tmp12_;
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_ui_set_state ((BoxesUI*) _tmp13_, BOXES_UI_STATE_COLLECTION);
#line 3826 "app.c"
	}
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp14_ = boxes_app_add_new_window (self);
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	window = _tmp14_;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp15_ = window;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp16_ = machine;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_window_connect_to (_tmp15_, _tmp16_);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (window);
#line 3840 "app.c"
}


void boxes_app_delete_machine (BoxesApp* self, BoxesMachine* machine, gboolean by_user) {
	BoxesMachine* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	BoxesCollection* _tmp2_ = NULL;
	BoxesMachine* _tmp3_ = NULL;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (machine != NULL);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = machine;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = by_user;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_machine_delete (_tmp0_, _tmp1_);
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = self->collection;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = machine;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_collection_remove_item (_tmp2_, (BoxesCollectionItem*) _tmp3_);
#line 3865 "app.c"
}


static void boxes_app_add_collection_source_data_free (gpointer _data) {
	BoxesAppAddCollectionSourceData* _data_;
	_data_ = _data;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->source);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->self);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_slice_free (BoxesAppAddCollectionSourceData, _data_);
#line 3878 "app.c"
}


void boxes_app_add_collection_source (BoxesApp* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesAppAddCollectionSourceData* _data_;
	BoxesApp* _tmp0_ = NULL;
	BoxesCollectionSource* _tmp1_ = NULL;
	BoxesCollectionSource* _tmp2_ = NULL;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = g_slice_new0 (BoxesAppAddCollectionSourceData);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_app_add_collection_source);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_app_add_collection_source_data_free);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->self = _tmp0_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = source;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->source);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->source = _tmp2_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_add_collection_source_co (_data_);
#line 3907 "app.c"
}


void boxes_app_add_collection_source_finish (BoxesApp* self, GAsyncResult* _res_) {
	BoxesAppAddCollectionSourceData* _data_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 3915 "app.c"
}


static void boxes_app_add_collection_source_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesAppAddCollectionSourceData* _data_;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = _user_data_;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_source_object_ = source_object;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_res_ = _res_;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_add_collection_source_co (_data_);
#line 3929 "app.c"
}


static gboolean boxes_app_add_collection_source_co (BoxesAppAddCollectionSourceData* _data_) {
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	static GQuark _tmp18_label0 = 0;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	static GQuark _tmp18_label1 = 0;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	switch (_data_->_state_) {
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case 0:
#line 3942 "app.c"
		goto _state_0;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case 1:
#line 3946 "app.c"
		goto _state_1;
		default:
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_assert_not_reached ();
#line 3951 "app.c"
	}
	_state_0:
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp0_ = NULL;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp0_ = _data_->source;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp1_ = FALSE;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp1_ = boxes_collection_source_get_enabled (_data_->_tmp0_);
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp2_ = FALSE;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (!_data_->_tmp2_) {
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (_data_->_state_ == 0) {
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3972 "app.c"
		} else {
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3976 "app.c"
		}
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_object_unref (_data_->_async_result);
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return FALSE;
#line 3982 "app.c"
	}
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp3_ = NULL;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp3_ = _data_->self->priv->sources;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp4_ = NULL;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp4_ = _data_->source;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp5_ = NULL;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp5_ = boxes_collection_source_get_name (_data_->_tmp4_);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp6_ = NULL;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp7_ = NULL;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp7_ = _data_->_tmp6_;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp8_ = NULL;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp8_ = g_hash_table_lookup (_data_->_tmp3_, _data_->_tmp7_);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp9_ = FALSE;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp9_ = ((BoxesCollectionSource*) _data_->_tmp8_) != NULL;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (_data_->_tmp7_);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_data_->_tmp9_) {
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp10_ = NULL;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp10_ = _data_->source;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp11_ = NULL;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp11_ = boxes_collection_source_get_name (_data_->_tmp10_);
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp12_ = NULL;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp12_ = _data_->_tmp11_;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp13_ = NULL;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp13_ = _data_->_tmp12_;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_warning ("app.vala:361: Attempt to add duplicate collection source '%s', ignorin" \
"g..", _data_->_tmp13_);
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_data_->_tmp13_);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (_data_->_state_ == 0) {
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4040 "app.c"
		} else {
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4044 "app.c"
		}
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_object_unref (_data_->_async_result);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return FALSE;
#line 4050 "app.c"
	}
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp14_ = NULL;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp14_ = _data_->source;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp15_ = NULL;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp15_ = boxes_collection_source_get_source_type (_data_->_tmp14_);
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp16_ = NULL;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp16_ = _data_->_tmp15_;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp17_ = NULL;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp19_ = 0U;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp17_ = _data_->_tmp16_;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp19_ = (NULL == _data_->_tmp17_) ? 0 : g_quark_from_string (_data_->_tmp17_);
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_free (_data_->_tmp17_);
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if ((_data_->_tmp19_ == ((0 != _tmp18_label0) ? _tmp18_label0 : (_tmp18_label0 = g_quark_from_static_string ("vnc")))) || (_data_->_tmp19_ == ((0 != _tmp18_label1) ? _tmp18_label1 : (_tmp18_label1 = g_quark_from_static_string ("spice"))))) {
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		switch (0) {
#line 4078 "app.c"
			default:
			{
				{
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp20_ = NULL;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp20_ = _data_->source;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp21_ = NULL;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp21_ = boxes_remote_machine_new (_data_->_tmp20_, &_data_->_inner_error_);
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->machine = _data_->_tmp21_;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
						if (_data_->_inner_error_->domain == BOXES_ERROR) {
#line 4096 "app.c"
							goto __catch2_boxes_error;
						}
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
						g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
						g_clear_error (&_data_->_inner_error_);
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
						return FALSE;
#line 4105 "app.c"
					}
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp22_ = NULL;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp22_ = _data_->self->collection;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp23_ = NULL;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp23_ = _data_->machine;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					boxes_collection_add_item (_data_->_tmp22_, (BoxesCollectionItem*) _data_->_tmp23_);
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_g_object_unref0 (_data_->machine);
#line 4119 "app.c"
				}
				goto __finally2;
				__catch2_boxes_error:
				{
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_error_ = _data_->_inner_error_;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_inner_error_ = NULL;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp24_ = NULL;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp24_ = _data_->_error_;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp25_ = NULL;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp25_ = _data_->_tmp24_->message;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					g_warning ("app.vala:372: %s", _data_->_tmp25_);
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_g_error_free0 (_data_->_error_);
#line 4140 "app.c"
				}
				__finally2:
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					g_clear_error (&_data_->_inner_error_);
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					return FALSE;
#line 4151 "app.c"
				}
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				break;
#line 4155 "app.c"
			}
		}
	} else {
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		switch (0) {
#line 4161 "app.c"
			default:
			{
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp26_ = NULL;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp26_ = _data_->self->priv->brokers;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp27_ = NULL;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp27_ = _data_->source;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp28_ = NULL;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp28_ = boxes_collection_source_get_source_type (_data_->_tmp27_);
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp29_ = NULL;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp29_ = _data_->_tmp28_;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp30_ = NULL;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp30_ = _data_->_tmp29_;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp31_ = NULL;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp31_ = g_hash_table_lookup (_data_->_tmp26_, _data_->_tmp30_);
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp32_ = NULL;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp32_ = _g_object_ref0 ((BoxesBroker*) _data_->_tmp31_);
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp33_ = NULL;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp33_ = _data_->_tmp32_;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_free0 (_data_->_tmp30_);
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->broker = _data_->_tmp33_;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp34_ = NULL;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp34_ = _data_->broker;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				if (_data_->_tmp34_ != NULL) {
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp35_ = NULL;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp35_ = _data_->broker;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp36_ = NULL;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp36_ = _data_->source;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_state_ = 1;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					boxes_broker_add_source (_data_->_tmp35_, _data_->_tmp36_, boxes_app_add_collection_source_ready, _data_);
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					return FALSE;
#line 4220 "app.c"
					_state_1:
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					boxes_broker_add_source_finish (_data_->_tmp35_, _data_->_res_);
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp37_ = NULL;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp37_ = _data_->self->priv->sources;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp38_ = NULL;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp38_ = _data_->source;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp39_ = NULL;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp39_ = boxes_collection_source_get_name (_data_->_tmp38_);
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp40_ = NULL;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp40_ = _data_->_tmp39_;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp41_ = NULL;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp41_ = _data_->source;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp42_ = NULL;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp42_ = _g_object_ref0 (_data_->_tmp41_);
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					g_hash_table_insert (_data_->_tmp37_, _data_->_tmp40_, _data_->_tmp42_);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp43_ = NULL;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp43_ = _data_->source;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp44_ = NULL;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp44_ = boxes_collection_source_get_name (_data_->_tmp43_);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp45_ = NULL;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp45_ = _data_->_tmp44_;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp46_ = NULL;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp46_ = _data_->_tmp45_;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp47_ = FALSE;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp47_ = g_strcmp0 (_data_->_tmp46_, BOXES_APP_DEFAULT_SOURCE_NAME) == 0;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_g_free0 (_data_->_tmp46_);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					if (_data_->_tmp47_) {
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
						g_object_notify ((GObject*) _data_->self, "default-connection");
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
						g_object_notify ((GObject*) _data_->self, "default-source");
#line 4278 "app.c"
					}
				} else {
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp48_ = NULL;
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp48_ = _data_->source;
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp49_ = NULL;
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp49_ = boxes_collection_source_get_source_type (_data_->_tmp48_);
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp50_ = NULL;
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp50_ = _data_->_tmp49_;
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp51_ = NULL;
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp51_ = _data_->_tmp50_;
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					g_warning ("app.vala:386: Unsupported source type %s", _data_->_tmp51_);
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_g_free0 (_data_->_tmp51_);
#line 4301 "app.c"
				}
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (_data_->broker);
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				break;
#line 4307 "app.c"
			}
		}
	}
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_data_->_state_ == 0) {
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4315 "app.c"
	} else {
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4319 "app.c"
	}
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_unref (_data_->_async_result);
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return FALSE;
#line 4325 "app.c"
}


static void boxes_app_setup_default_source_data_free (gpointer _data) {
	BoxesAppSetupDefaultSourceData* _data_;
	_data_ = _data;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->self);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_slice_free (BoxesAppSetupDefaultSourceData, _data_);
#line 4336 "app.c"
}


static void boxes_app_setup_default_source (BoxesApp* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesAppSetupDefaultSourceData* _data_;
	BoxesApp* _tmp0_ = NULL;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = g_slice_new0 (BoxesAppSetupDefaultSourceData);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_app_setup_default_source);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_app_setup_default_source_data_free);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->self = _tmp0_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_setup_default_source_co (_data_);
#line 4355 "app.c"
}


static void boxes_app_setup_default_source_finish (BoxesApp* self, GAsyncResult* _res_) {
	BoxesAppSetupDefaultSourceData* _data_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 4363 "app.c"
}


static void boxes_app_setup_default_source_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesAppSetupDefaultSourceData* _data_;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = _user_data_;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_source_object_ = source_object;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_res_ = _res_;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_setup_default_source_co (_data_);
#line 4377 "app.c"
}


static gboolean boxes_app_setup_default_source_co (BoxesAppSetupDefaultSourceData* _data_) {
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	switch (_data_->_state_) {
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case 0:
#line 4386 "app.c"
		goto _state_0;
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case 1:
#line 4390 "app.c"
		goto _state_1;
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case 2:
#line 4394 "app.c"
		goto _state_2;
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case 3:
#line 4398 "app.c"
		goto _state_3;
		default:
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_assert_not_reached ();
#line 4403 "app.c"
	}
	_state_0:
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp0_ = NULL;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp0_ = boxes_get_user_pkgconfig_source (BOXES_APP_DEFAULT_SOURCE_NAME);
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->path = _data_->_tmp0_;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->create_session_source = TRUE;
#line 4414 "app.c"
	{
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp1_ = NULL;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp1_ = g_file_new_for_path (_data_->path);
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->file = _data_->_tmp1_;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_state_ = 1;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_file_query_info_async (_data_->file, G_FILE_ATTRIBUTE_STANDARD_SIZE, G_FILE_QUERY_INFO_NONE, G_PRIORITY_DEFAULT, NULL, boxes_app_setup_default_source_ready, _data_);
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return FALSE;
#line 4428 "app.c"
		_state_1:
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp2_ = NULL;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp2_ = g_file_query_info_finish (_data_->file, _data_->_res_, &_data_->_inner_error_);
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->info = _data_->_tmp2_;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_g_object_unref0 (_data_->file);
#line 4440 "app.c"
			goto __catch3_g_error;
		}
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp3_ = 0ULL;
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp3_ = g_file_info_get_attribute_uint64 (_data_->info, G_FILE_ATTRIBUTE_STANDARD_SIZE);
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->create_session_source = _data_->_tmp3_ <= ((guint64) 0);
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (_data_->info);
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (_data_->file);
#line 4453 "app.c"
	}
	goto __finally3;
	__catch3_g_error:
	{
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_inner_error_ = NULL;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp4_ = NULL;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp4_ = _data_->_error_;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp5_ = NULL;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp5_ = _data_->_tmp4_->message;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_debug ("app.vala:403: Failed to query '%s': %s. Assuming it doesn't exist.", _data_->path, _data_->_tmp5_);
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_error_free0 (_data_->_error_);
#line 4474 "app.c"
	}
	__finally3:
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_data_->path);
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_clear_error (&_data_->_inner_error_);
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return FALSE;
#line 4487 "app.c"
	}
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp6_ = FALSE;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp6_ = _data_->create_session_source;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_data_->_tmp6_) {
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp7_ = NULL;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp7_ = boxes_get_pkgdata_source ("QEMU_Session");
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp8_ = NULL;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp8_ = _data_->_tmp7_;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp9_ = NULL;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp9_ = g_file_new_for_path (_data_->_tmp8_);
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp10_ = NULL;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp10_ = _data_->_tmp9_;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_data_->_tmp8_);
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->src = _data_->_tmp10_;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp11_ = NULL;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp11_ = g_file_new_for_path (_data_->path);
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->dst = _data_->_tmp11_;
#line 4521 "app.c"
		{
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp12_ = NULL;
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp12_ = _data_->src;
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp13_ = NULL;
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp13_ = _data_->dst;
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_state_ = 2;
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			g_file_copy_async (_data_->_tmp12_, _data_->_tmp13_, G_FILE_COPY_OVERWRITE, G_PRIORITY_DEFAULT, NULL, NULL, NULL, boxes_app_setup_default_source_ready, _data_);
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			return FALSE;
#line 4537 "app.c"
			_state_2:
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			g_file_copy_finish (_data_->_tmp12_, _data_->_res_, &_data_->_inner_error_);
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 4543 "app.c"
				goto __catch4_g_error;
			}
		}
		goto __finally4;
		__catch4_g_error:
		{
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_vala1__error_ = _data_->_inner_error_;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_inner_error_ = NULL;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp14_ = NULL;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp14_ = _data_->_vala1__error_;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp15_ = NULL;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp15_ = _data_->_tmp14_->message;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			g_critical ("app.vala:412: Can't setup default sources: %s", _data_->_tmp15_);
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_g_error_free0 (_data_->_vala1__error_);
#line 4566 "app.c"
		}
		__finally4:
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_g_object_unref0 (_data_->dst);
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_g_object_unref0 (_data_->src);
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_g_free0 (_data_->path);
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			g_clear_error (&_data_->_inner_error_);
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			return FALSE;
#line 4583 "app.c"
		}
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (_data_->dst);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (_data_->src);
#line 4589 "app.c"
	}
	{
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp16_ = NULL;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp16_ = boxes_collection_source_new_with_file (BOXES_APP_DEFAULT_SOURCE_NAME, &_data_->_inner_error_);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->source = _data_->_tmp16_;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 4600 "app.c"
			goto __catch5_g_error;
		}
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_state_ = 3;
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_app_add_collection_source (_data_->self, _data_->source, boxes_app_setup_default_source_ready, _data_);
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return FALSE;
#line 4609 "app.c"
		_state_3:
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_app_add_collection_source_finish (_data_->self, _data_->_res_);
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (_data_->source);
#line 4615 "app.c"
	}
	goto __finally5;
	__catch5_g_error:
	{
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_vala2__error_ = _data_->_inner_error_;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_inner_error_ = NULL;
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp17_ = NULL;
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp17_ = _data_->_vala2__error_;
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp18_ = NULL;
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp18_ = _data_->_tmp17_->message;
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_printerr ("Error setting up default broker: %s\n", _data_->_tmp18_);
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_application_release ((GApplication*) _data_->self);
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_error_free0 (_data_->_vala2__error_);
#line 4638 "app.c"
	}
	__finally5:
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_data_->path);
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_clear_error (&_data_->_inner_error_);
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return FALSE;
#line 4651 "app.c"
	}
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp19_ = NULL;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp19_ = boxes_app_get_default_connection (_data_->self);
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp20_ = NULL;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp20_ = _data_->_tmp19_;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp21_ = NULL;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp21_ = _data_->_tmp20_;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_vala_assert (_data_->_tmp21_ != NULL, "default_connection != null");
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->_tmp21_);
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (_data_->path);
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_data_->_state_ == 0) {
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4675 "app.c"
	} else {
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4679 "app.c"
	}
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_unref (_data_->_async_result);
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return FALSE;
#line 4685 "app.c"
}


void boxes_app_notify_machine_installed (BoxesApp* self, BoxesMachine* machine) {
	BoxesMachine* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesAppWindow* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
	gchar* msg = NULL;
	const gchar* _tmp5_ = NULL;
	BoxesMachine* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	GNotification* notification = NULL;
	const gchar* _tmp10_ = NULL;
	GNotification* _tmp11_ = NULL;
	GNotification* _tmp12_ = NULL;
	BoxesMachine* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
	const gchar* _tmp15_ = NULL;
	gchar* _tmp16_ = NULL;
	gchar* _tmp17_ = NULL;
	GNotification* _tmp18_ = NULL;
#line 427 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 427 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (machine != NULL);
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = machine;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = boxes_machine_get_window (_tmp0_);
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _tmp1_;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_get ((GtkWindow*) _tmp2_, "is-active", &_tmp3_, NULL);
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = _tmp3_;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp4_) {
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_debug ("app.vala:429: Window is focused, no need for system notification");
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return;
#line 4731 "app.c"
	}
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = _ ("Box '%s' installed and ready to use");
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = machine;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp6_);
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp8_ = _tmp7_;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp9_ = g_strdup_printf (_tmp5_, _tmp8_);
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	msg = _tmp9_;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp10_ = msg;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp11_ = g_notification_new (_tmp10_);
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	notification = _tmp11_;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp12_ = notification;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp13_ = machine;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp14_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp13_);
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp15_ = _tmp14_;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp16_ = g_strconcat ("app.launch-box::", _tmp15_, NULL);
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp17_ = _tmp16_;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_notification_add_button (_tmp12_, "Launch", _tmp17_);
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (_tmp17_);
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp18_ = notification;
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_application_send_notification ((GApplication*) self, NULL, _tmp18_);
#line 427 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (notification);
#line 427 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (msg);
#line 4775 "app.c"
}


static void boxes_app_setup_sources_data_free (gpointer _data) {
	BoxesAppSetupSourcesData* _data_;
	_data_ = _data;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->self);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_slice_free (BoxesAppSetupSourcesData, _data_);
#line 4786 "app.c"
}


static void boxes_app_setup_sources (BoxesApp* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesAppSetupSourcesData* _data_;
	BoxesApp* _tmp0_ = NULL;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = g_slice_new0 (BoxesAppSetupSourcesData);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_app_setup_sources);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_app_setup_sources_data_free);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->self = _tmp0_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_setup_sources_co (_data_);
#line 4805 "app.c"
}


static void boxes_app_setup_sources_finish (BoxesApp* self, GAsyncResult* _res_) {
	BoxesAppSetupSourcesData* _data_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 4813 "app.c"
}


static Block7Data* block7_data_ref (Block7Data* _data7_) {
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data7_->_ref_count_);
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return _data7_;
#line 4822 "app.c"
}


static void block7_data_unref (void * _userdata_) {
	Block7Data* _data7_;
	_data7_ = (Block7Data*) _userdata_;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data7_->_ref_count_)) {
#line 4831 "app.c"
		BoxesApp* self;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data7_->self;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		__g_list_free__g_object_unref0_0 (_data7_->new_sources);
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (self);
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block7Data, _data7_);
#line 4841 "app.c"
	}
}


static gboolean __lambda244_ (Block7Data* _data7_, const gchar* filename, GError** error) {
	BoxesApp* self;
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	BoxesCollectionSource* source = NULL;
	const gchar* _tmp1_ = NULL;
	BoxesCollectionSource* _tmp2_ = NULL;
	BoxesCollectionSource* _tmp3_ = NULL;
	BoxesCollectionSource* _tmp4_ = NULL;
	GError * _inner_error_ = NULL;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data7_->self;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (filename != NULL, FALSE);
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = filename;
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_strcmp0 (_tmp0_, BOXES_APP_DEFAULT_SOURCE_NAME) == 0) {
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		result = FALSE;
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return result;
#line 4868 "app.c"
	}
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = filename;
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = boxes_collection_source_new_with_file (_tmp1_, &_inner_error_);
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	source = _tmp2_;
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_propagate_error (error, _inner_error_);
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return FALSE;
#line 4882 "app.c"
	}
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = source;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data7_->new_sources = g_list_append (_data7_->new_sources, _tmp4_);
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = FALSE;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (source);
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 4896 "app.c"
}


static gboolean ___lambda244__boxes_foreach_filename_from_dir_func (const gchar* filename, gpointer self, GError** error) {
	gboolean result;
	result = __lambda244_ (self, filename, error);
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 4905 "app.c"
}


static void boxes_app_setup_sources_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesAppSetupSourcesData* _data_;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = _user_data_;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_source_object_ = source_object;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_res_ = _res_;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_setup_sources_co (_data_);
#line 4919 "app.c"
}


static gboolean boxes_app_setup_sources_co (BoxesAppSetupSourcesData* _data_) {
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	switch (_data_->_state_) {
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case 0:
#line 4928 "app.c"
		goto _state_0;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case 1:
#line 4932 "app.c"
		goto _state_1;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case 2:
#line 4936 "app.c"
		goto _state_2;
		default:
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_assert_not_reached ();
#line 4941 "app.c"
	}
	_state_0:
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_data7_ = g_slice_new0 (Block7Data);
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_data7_->_ref_count_ = 1;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_data7_->self = g_object_ref (_data_->self);
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_data7_->_async_data_ = _data_;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp0_ = NULL;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp0_ = boxes_get_user_pkgconfig_source (NULL);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp1_ = NULL;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp2_ = NULL;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp2_ = g_file_new_for_path (_data_->_tmp1_);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp3_ = NULL;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp3_ = _data_->_tmp2_;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (_data_->_tmp1_);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->dir = _data_->_tmp3_;
#line 443 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_data7_->new_sources = NULL;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp4_ = NULL;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp4_ = _data_->dir;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_state_ = 1;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_foreach_filename_from_dir (_data_->_tmp4_, ___lambda244__boxes_foreach_filename_from_dir_func, _data_->_data7_, boxes_app_setup_sources_ready, _data_);
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return FALSE;
#line 4984 "app.c"
	_state_1:
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_foreach_filename_from_dir_finish (_data_->_res_);
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp5_ = NULL;
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp5_ = _data_->_data7_->new_sources;
#line 4992 "app.c"
	{
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->source_collection = _data_->_tmp5_;
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		for (_data_->source_it = _data_->source_collection; _data_->source_it != NULL; _data_->source_it = _data_->source_it->next) {
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp6_ = NULL;
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp6_ = _g_object_ref0 ((BoxesCollectionSource*) _data_->source_it->data);
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->source = _data_->_tmp6_;
#line 5004 "app.c"
			{
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp7_ = NULL;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp7_ = _data_->source;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_state_ = 2;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_app_add_collection_source (_data_->self, _data_->_tmp7_, boxes_app_setup_sources_ready, _data_);
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				return FALSE;
#line 5016 "app.c"
				_state_2:
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_app_add_collection_source_finish (_data_->self, _data_->_res_);
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (_data_->source);
#line 5022 "app.c"
			}
		}
	}
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp8_ = NULL;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp8_ = boxes_app_get_default_connection (_data_->self);
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp9_ = NULL;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp9_ = _data_->_tmp8_;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp10_ = NULL;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp10_ = _data_->_tmp9_;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp11_ = FALSE;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp11_ = _data_->_tmp10_ == NULL;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->_tmp10_);
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_data_->_tmp11_) {
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_printerr ("Missing or failing default libvirt connection\n");
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_application_release ((GApplication*) _data_->self);
#line 5050 "app.c"
	}
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->dir);
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	block7_data_unref (_data_->_data7_);
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_data7_ = NULL;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_data_->_state_ == 0) {
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5062 "app.c"
	} else {
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5066 "app.c"
	}
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_unref (_data_->_async_result);
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return FALSE;
#line 5072 "app.c"
}


static Block8Data* block8_data_ref (Block8Data* _data8_) {
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data8_->_ref_count_);
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return _data8_;
#line 5081 "app.c"
}


static void block8_data_unref (void * _userdata_) {
	Block8Data* _data8_;
	_data8_ = (Block8Data*) _userdata_;
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data8_->_ref_count_)) {
#line 5090 "app.c"
		BoxesApp* self;
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data8_->self;
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (self);
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block8Data, _data8_);
#line 5098 "app.c"
	}
}


static Block9Data* block9_data_ref (Block9Data* _data9_) {
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data9_->_ref_count_);
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return _data9_;
#line 5108 "app.c"
}


static void block9_data_unref (void * _userdata_) {
	Block9Data* _data9_;
	_data9_ = (Block9Data*) _userdata_;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data9_->_ref_count_)) {
#line 5117 "app.c"
		BoxesApp* self;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data9_->_data8_->self;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (_data9_->machine);
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		block8_data_unref (_data9_->_data8_);
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data9_->_data8_ = NULL;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block9Data, _data9_);
#line 5129 "app.c"
	}
}


static void ______lambda248_ (Block9Data* _data9_) {
	Block8Data* _data8_;
	BoxesApp* self;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gint _tmp3_ = 0;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data8_ = _data9_->_data8_;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data8_->self;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _data9_->machine;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp0_);
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _tmp1_;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_debug ("app.vala:484: %s suspended", _tmp2_);
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = _data8_->waiting_counter;
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data8_->waiting_counter = _tmp3_ - 1;
#line 5157 "app.c"
}


static void _______lambda248__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	______lambda248_ (self);
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	block9_data_unref (self);
#line 5166 "app.c"
}


static void boxes_app_suspend_machines (BoxesApp* self) {
	Block8Data* _data8_;
	BoxesCollection* _tmp0_ = NULL;
	GMainContext* context = NULL;
	GMainContext* _tmp1_ = NULL;
	GMainContext* _tmp2_ = NULL;
	BoxesCollection* _tmp3_ = NULL;
	GPtrArray* _tmp4_ = NULL;
	gpointer* _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
	GMainContext* _tmp15_ = NULL;
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data8_ = g_slice_new0 (Block8Data);
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data8_->_ref_count_ = 1;
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data8_->self = g_object_ref (self);
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->collection;
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp0_ == NULL) {
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		block8_data_unref (_data8_);
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data8_ = NULL;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return;
#line 5199 "app.c"
	}
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_debug ("app.vala:468: Suspending running boxes");
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data8_->waiting_counter = 0;
#line 474 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = g_main_context_new ();
#line 474 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	context = _tmp1_;
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = context;
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_main_context_push_thread_default (_tmp2_);
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = self->collection;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = _tmp3_->items;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = _tmp4_->pdata;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5__length1 = (gint) _tmp4_->len;
#line 5221 "app.c"
	{
		BoxesCollectionItem** item_collection = NULL;
		gint item_collection_length1 = 0;
		gint _item_collection_size_ = 0;
		gint item_it = 0;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection = _tmp5_;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection_length1 = _tmp5__length1;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		for (item_it = 0; item_it < _tmp5__length1; item_it = item_it + 1) {
#line 5233 "app.c"
			BoxesCollectionItem* _tmp6_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp6_ = _g_object_ref0 (item_collection[item_it]);
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			item = _tmp6_;
#line 5240 "app.c"
			{
				BoxesCollectionItem* _tmp7_ = NULL;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp7_ = item;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, BOXES_TYPE_LIBVIRT_MACHINE)) {
#line 5247 "app.c"
					Block9Data* _data9_;
					BoxesCollectionItem* _tmp8_ = NULL;
					BoxesLibvirtMachine* _tmp9_ = NULL;
					BoxesLibvirtMachine* _tmp10_ = NULL;
					gboolean _tmp11_ = FALSE;
					gboolean _tmp12_ = FALSE;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data9_ = g_slice_new0 (Block9Data);
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data9_->_ref_count_ = 1;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data9_->_data8_ = block8_data_ref (_data8_);
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp8_ = item;
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp8_) : NULL);
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data9_->machine = _tmp9_;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp10_ = _data9_->machine;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp11_ = boxes_machine_get_suspend_at_exit ((BoxesMachine*) _tmp10_);
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp12_ = _tmp11_;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					if (_tmp12_) {
#line 5274 "app.c"
						gint _tmp13_ = 0;
						BoxesLibvirtMachine* _tmp14_ = NULL;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
						_tmp13_ = _data8_->waiting_counter;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
						_data8_->waiting_counter = _tmp13_ + 1;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
						_tmp14_ = _data9_->machine;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
						boxes_libvirt_machine_suspend (_tmp14_, _______lambda248__gasync_ready_callback, block9_data_ref (_data9_));
#line 5285 "app.c"
					}
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					block9_data_unref (_data9_);
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data9_ = NULL;
#line 5291 "app.c"
				}
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (item);
#line 5295 "app.c"
			}
		}
	}
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp15_ = context;
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_main_context_pop_thread_default (_tmp15_);
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	while (TRUE) {
#line 5305 "app.c"
		gint _tmp16_ = 0;
		GMainContext* _tmp17_ = NULL;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp16_ = _data8_->waiting_counter;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (!(_tmp16_ > 0)) {
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			break;
#line 5314 "app.c"
		}
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp17_ = context;
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_main_context_iteration (_tmp17_, TRUE);
#line 5320 "app.c"
	}
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_debug ("app.vala:496: Running boxes suspended");
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_main_context_unref0 (context);
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	block8_data_unref (_data8_);
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data8_ = NULL;
#line 5330 "app.c"
}


/**
     * Deletes specified items, while allowing user to undo it.
     *
     * @param items the list of machines
     * @param message optional message to be shown together with the undo button. If not provided, an appropriate messsage
     *                is created.
     * @param callback optional function that, if provided, is called after the undo operation
     *
     * @attention the ownership for items is required since GLib.List is a compact class.
     */
static Block10Data* block10_data_ref (Block10Data* _data10_) {
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data10_->_ref_count_);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return _data10_;
#line 5349 "app.c"
}


static void block10_data_unref (void * _userdata_) {
	Block10Data* _data10_;
	_data10_ = (Block10Data*) _userdata_;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data10_->_ref_count_)) {
#line 5358 "app.c"
		BoxesApp* self;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data10_->self;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		__g_list_free__g_object_unref0_0 (_data10_->items);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		(_data10_->undo_notify_callback_target_destroy_notify == NULL) ? NULL : (_data10_->undo_notify_callback_target_destroy_notify (_data10_->undo_notify_callback_target), NULL);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data10_->undo_notify_callback = NULL;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data10_->undo_notify_callback_target = NULL;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data10_->undo_notify_callback_target_destroy_notify = NULL;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (self);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block10Data, _data10_);
#line 5376 "app.c"
	}
}


static void __lambda85_ (Block10Data* _data10_) {
	BoxesApp* self;
	GList* _tmp0_ = NULL;
	BoxesAppUndoNotifyCallback _tmp6_ = NULL;
	void* _tmp6__target = NULL;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data10_->self;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_debug ("app.vala:530: Box deletion cancelled by user. Re-adding to view");
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _data10_->items;
#line 5392 "app.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection = _tmp0_;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 5400 "app.c"
			BoxesCollectionItem* _tmp1_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp1_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			item = _tmp1_;
#line 5407 "app.c"
			{
				BoxesMachine* machine = NULL;
				BoxesCollectionItem* _tmp2_ = NULL;
				BoxesMachine* _tmp3_ = NULL;
				BoxesCollection* _tmp4_ = NULL;
				BoxesMachine* _tmp5_ = NULL;
#line 532 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp2_ = item;
#line 532 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp2_) : NULL);
#line 532 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				machine = _tmp3_;
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp4_ = self->collection;
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp5_ = machine;
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_collection_add_item (_tmp4_, (BoxesCollectionItem*) _tmp5_);
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (machine);
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (item);
#line 5430 "app.c"
			}
		}
	}
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = _data10_->undo_notify_callback;
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6__target = _data10_->undo_notify_callback_target;
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp6_ != NULL) {
#line 5440 "app.c"
		BoxesAppUndoNotifyCallback _tmp7_ = NULL;
		void* _tmp7__target = NULL;
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp7_ = _data10_->undo_notify_callback;
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp7__target = _data10_->undo_notify_callback_target;
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp7_ (_tmp7__target);
#line 5449 "app.c"
	}
}


static void ___lambda85__boxes_notification_ok_func (gpointer self) {
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda85_ (self);
#line 5457 "app.c"
}


static void __lambda86_ (Block10Data* _data10_) {
	BoxesApp* self;
	GList* _tmp0_ = NULL;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data10_->self;
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_debug ("app.vala:540: User did not cancel deletion. Deleting now...");
#line 541 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _data10_->items;
#line 5470 "app.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 541 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection = _tmp0_;
#line 541 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 5478 "app.c"
			BoxesCollectionItem* _tmp1_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 541 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp1_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 541 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			item = _tmp1_;
#line 5485 "app.c"
			{
				BoxesCollectionItem* _tmp2_ = NULL;
				BoxesCollectionItem* _tmp3_ = NULL;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp2_ = item;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_MACHINE)) {
#line 543 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_g_object_unref0 (item);
#line 543 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					continue;
#line 5497 "app.c"
				}
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp3_ = item;
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_machine_delete (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp3_) : NULL, TRUE);
#line 541 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (item);
#line 5505 "app.c"
			}
		}
	}
}


static void ___lambda86__boxes_notification_cancel_func (gpointer self) {
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda86_ (self);
#line 5515 "app.c"
}


void boxes_app_delete_machines_undoable (BoxesApp* self, GList* items, const gchar* message, BoxesAppUndoNotifyCallback undo_notify_callback, void* undo_notify_callback_target, GDestroyNotify undo_notify_callback_target_destroy_notify) {
	Block10Data* _data10_;
	GList* _tmp0_ = NULL;
	BoxesAppUndoNotifyCallback _tmp1_ = NULL;
	void* _tmp1__target = NULL;
	guint num_items = 0U;
	GList* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	guint _tmp4_ = 0U;
	gchar* msg = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	GList* _tmp21_ = NULL;
	BoxesNotificationOKFunc undo = NULL;
	void* undo_target = NULL;
	GDestroyNotify undo_target_destroy_notify = NULL;
	BoxesNotificationCancelFunc really_remove = NULL;
	void* really_remove_target = NULL;
	GDestroyNotify really_remove_target_destroy_notify = NULL;
	BoxesAppWindow* _tmp25_ = NULL;
	BoxesAppWindow* _tmp26_ = NULL;
	BoxesNotificationbar* _tmp27_ = NULL;
	BoxesNotificationbar* _tmp28_ = NULL;
	const gchar* _tmp29_ = NULL;
	const gchar* _tmp30_ = NULL;
	BoxesNotificationOKFunc _tmp31_ = NULL;
	void* _tmp31__target = NULL;
	GDestroyNotify _tmp31__target_destroy_notify = NULL;
	BoxesNotificationCancelFunc _tmp32_ = NULL;
	void* _tmp32__target = NULL;
	GDestroyNotify _tmp32__target_destroy_notify = NULL;
	GdNotification* _tmp33_ = NULL;
	GdNotification* _tmp34_ = NULL;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data10_ = g_slice_new0 (Block10Data);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data10_->_ref_count_ = 1;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data10_->self = g_object_ref (self);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = items;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__g_list_free__g_object_unref0_0 (_data10_->items);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data10_->items = _tmp0_;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = undo_notify_callback;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1__target = undo_notify_callback_target;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	(_data10_->undo_notify_callback_target_destroy_notify == NULL) ? NULL : (_data10_->undo_notify_callback_target_destroy_notify (_data10_->undo_notify_callback_target), NULL);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data10_->undo_notify_callback = NULL;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data10_->undo_notify_callback_target = NULL;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data10_->undo_notify_callback_target_destroy_notify = NULL;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data10_->undo_notify_callback = _tmp1_;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data10_->undo_notify_callback_target = _tmp1__target;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data10_->undo_notify_callback_target_destroy_notify = undo_notify_callback_target_destroy_notify;
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _data10_->items;
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = g_list_length (_tmp2_);
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	num_items = _tmp3_;
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = num_items;
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp4_ == ((guint) 0)) {
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		block10_data_unref (_data10_);
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data10_ = NULL;
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return;
#line 5601 "app.c"
	}
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = message;
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = g_strdup (_tmp5_);
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	msg = _tmp6_;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = msg;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp7_ == NULL) {
#line 5613 "app.c"
		gchar* _tmp8_ = NULL;
		guint _tmp9_ = 0U;
		gchar* _tmp20_ = NULL;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp9_ = num_items;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (_tmp9_ == ((guint) 1)) {
#line 5621 "app.c"
			const gchar* _tmp10_ = NULL;
			GList* _tmp11_ = NULL;
			gconstpointer _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
			gchar* _tmp15_ = NULL;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp10_ = _ ("Box '%s' has been deleted");
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp11_ = _data10_->items;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp12_ = _tmp11_->data;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp13_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp12_);
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp14_ = _tmp13_;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp15_ = g_strdup_printf (_tmp10_, _tmp14_);
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_g_free0 (_tmp8_);
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp8_ = _tmp15_;
#line 5644 "app.c"
		} else {
			guint _tmp16_ = 0U;
			const gchar* _tmp17_ = NULL;
			guint _tmp18_ = 0U;
			gchar* _tmp19_ = NULL;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp16_ = num_items;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp17_ = ngettext ("%u box has been deleted", "%u boxes have been deleted", (gulong) _tmp16_);
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp18_ = num_items;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp19_ = g_strdup_printf (_tmp17_, _tmp18_);
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_g_free0 (_tmp8_);
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp8_ = _tmp19_;
#line 5662 "app.c"
		}
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp20_ = g_strdup (_tmp8_);
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (msg);
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		msg = _tmp20_;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_tmp8_);
#line 5672 "app.c"
	}
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp21_ = _data10_->items;
#line 5676 "app.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection = _tmp21_;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 5684 "app.c"
			BoxesCollectionItem* _tmp22_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp22_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			item = _tmp22_;
#line 5691 "app.c"
			{
				BoxesCollection* _tmp23_ = NULL;
				BoxesCollectionItem* _tmp24_ = NULL;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp23_ = self->collection;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp24_ = item;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_collection_remove_item (_tmp23_, _tmp24_);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (item);
#line 5703 "app.c"
			}
		}
	}
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	undo = ___lambda85__boxes_notification_ok_func;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	undo_target = block10_data_ref (_data10_);
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	undo_target_destroy_notify = block10_data_unref;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	really_remove = ___lambda86__boxes_notification_cancel_func;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	really_remove_target = block10_data_ref (_data10_);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	really_remove_target_destroy_notify = block10_data_unref;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp25_ = boxes_app_get_main_window (self);
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp26_ = _tmp25_;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp27_ = boxes_app_window_get_notificationbar (_tmp26_);
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp28_ = _tmp27_;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp29_ = msg;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp30_ = _ ("_Undo");
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp31_ = undo;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp31__target = undo_target;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp31__target_destroy_notify = undo_target_destroy_notify;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	undo_target_destroy_notify = NULL;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp32_ = really_remove;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp32__target = really_remove_target;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp32__target_destroy_notify = really_remove_target_destroy_notify;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	really_remove_target_destroy_notify = NULL;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp33_ = boxes_notificationbar_display_for_action (_tmp28_, _tmp29_, _tmp30_, _tmp31_, _tmp31__target, _tmp31__target_destroy_notify, _tmp32_, _tmp32__target, _tmp32__target_destroy_notify, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp34_ = _tmp33_;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_tmp34_);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	(really_remove_target_destroy_notify == NULL) ? NULL : (really_remove_target_destroy_notify (really_remove_target), NULL);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	really_remove = NULL;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	really_remove_target = NULL;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	really_remove_target_destroy_notify = NULL;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	(undo_target_destroy_notify == NULL) ? NULL : (undo_target_destroy_notify (undo_target), NULL);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	undo = NULL;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	undo_target = NULL;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	undo_target_destroy_notify = NULL;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (msg);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	block10_data_unref (_data10_);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data10_ = NULL;
#line 5775 "app.c"
}


void boxes_app_remove_selected_items (BoxesApp* self) {
	GList* selected_items = NULL;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesICollectionView* _tmp2_ = NULL;
	BoxesICollectionView* _tmp3_ = NULL;
	GList* _tmp4_ = NULL;
	BoxesAppWindow* _tmp5_ = NULL;
	BoxesAppWindow* _tmp6_ = NULL;
	GList* _tmp7_ = NULL;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_get_main_window (self);
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_;
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = boxes_app_window_get_view (_tmp1_);
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = _tmp2_;
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = boxes_icollection_view_get_selected_items (_tmp3_);
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	selected_items = _tmp4_;
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = boxes_app_get_main_window (self);
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = _tmp5_;
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_window_set_selection_mode (_tmp6_, FALSE);
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = selected_items;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	selected_items = NULL;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_delete_machines_undoable (self, _tmp7_, NULL, NULL, NULL, NULL);
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__g_list_free__g_object_unref0_0 (selected_items);
#line 5817 "app.c"
}


BoxesAppWindow* boxes_app_add_new_window (BoxesApp* self) {
	BoxesAppWindow* result = NULL;
	BoxesAppWindow* window = NULL;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
#line 561 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 562 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_window_new ((GtkApplication*) self);
#line 562 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_ref_sink (_tmp0_);
#line 562 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	window = _tmp0_;
#line 564 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _g_object_ref0 (window);
#line 564 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->windows = g_list_append (self->priv->windows, _tmp1_);
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_window_setup_ui (window);
#line 566 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_window_present ((GtkWindow*) window);
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_notify ((GObject*) self, "main-window");
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = window;
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 5848 "app.c"
}


static void ___lambda26_ (BoxesApp* self, BoxesICollectionView* view) {
	BoxesCollection* _tmp0_ = NULL;
	BoxesICollectionView* _tmp1_ = NULL;
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (view != NULL);
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->collection;
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = view;
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_collection_populate (_tmp0_, _tmp1_);
#line 5863 "app.c"
}


static void ____lambda26__gfunc (gconstpointer data, gpointer self) {
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	___lambda26_ ((BoxesApp*) self, (BoxesICollectionView*) data);
#line 5870 "app.c"
}


gboolean boxes_app_remove_window (BoxesApp* self, BoxesAppWindow* window) {
	gboolean result = FALSE;
	guint initial_windows_count = 0U;
	GList* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	gboolean window_was_main = FALSE;
	BoxesAppWindow* _tmp2_ = NULL;
	BoxesAppWindow* _tmp3_ = NULL;
	BoxesAppWindow* _tmp4_ = NULL;
	BoxesAppWindow* _tmp5_ = NULL;
	BoxesCollectionItem* _tmp6_ = NULL;
	BoxesCollectionItem* _tmp7_ = NULL;
	BoxesAppWindow* _tmp11_ = NULL;
	BoxesAppWindow* _tmp12_ = NULL;
	BoxesAppWindow* _tmp13_ = NULL;
	GList* _tmp14_ = NULL;
	guint _tmp15_ = 0U;
	gboolean _tmp17_ = FALSE;
	guint _tmp20_ = 0U;
	GList* _tmp21_ = NULL;
	guint _tmp22_ = 0U;
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (window != NULL, FALSE);
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->priv->windows;
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = g_list_length (_tmp0_);
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	initial_windows_count = _tmp1_;
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = window;
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = boxes_app_get_main_window (self);
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = _tmp3_;
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	window_was_main = _tmp2_ == _tmp4_;
#line 577 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = window;
#line 577 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = boxes_app_window_get_current_item (_tmp5_);
#line 577 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = _tmp6_;
#line 577 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp7_ != NULL) {
#line 5921 "app.c"
		BoxesAppWindow* _tmp8_ = NULL;
		BoxesCollectionItem* _tmp9_ = NULL;
		BoxesCollectionItem* _tmp10_ = NULL;
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp8_ = window;
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp9_ = boxes_app_window_get_current_item (_tmp8_);
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp10_ = _tmp9_;
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_machine_set_window (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp10_) : NULL, NULL);
#line 5933 "app.c"
	}
#line 580 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp11_ = window;
#line 580 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_widget_hide ((GtkWidget*) _tmp11_);
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp12_ = window;
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->windows = g_list_remove (self->priv->windows, _tmp12_);
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp13_ = window;
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_application_remove_window (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_application_get_type (), GtkApplication), (GtkWindow*) _tmp13_);
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp14_ = self->priv->windows;
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp15_ = g_list_length (_tmp14_);
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp15_ == ((guint) 0)) {
#line 5953 "app.c"
		gboolean _tmp16_ = FALSE;
#line 585 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp16_ = boxes_app_quit_app (self);
#line 585 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		result = _tmp16_;
#line 585 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return result;
#line 5961 "app.c"
	}
#line 589 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp17_ = window_was_main;
#line 589 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp17_) {
#line 5967 "app.c"
		BoxesAppWindow* _tmp18_ = NULL;
		BoxesAppWindow* _tmp19_ = NULL;
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp18_ = boxes_app_get_main_window (self);
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp19_ = _tmp18_;
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_app_window_foreach_view (_tmp19_, ____lambda26__gfunc, self);
#line 5976 "app.c"
	}
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_notify ((GObject*) self, "main-window");
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp20_ = initial_windows_count;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp21_ = self->priv->windows;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp22_ = g_list_length (_tmp21_);
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = _tmp20_ != _tmp22_;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 5990 "app.c"
}


BoxesAppWindow* boxes_app_get_main_window (BoxesApp* self) {
	BoxesAppWindow* result;
	BoxesAppWindow* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
	guint _tmp2_ = 0U;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = self->priv->windows;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = g_list_length (_tmp1_);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp2_ > ((guint) 0)) {
#line 6007 "app.c"
		GList* _tmp3_ = NULL;
		gconstpointer _tmp4_ = NULL;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp3_ = self->priv->windows;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp4_ = _tmp3_->data;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp0_ = (BoxesAppWindow*) _tmp4_;
#line 6016 "app.c"
	} else {
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp0_ = NULL;
#line 6020 "app.c"
	}
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = _tmp0_;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 6026 "app.c"
}


const gchar* boxes_app_get_uri (BoxesApp* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->priv->_uri;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = _tmp0_;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 6041 "app.c"
}


void boxes_app_set_uri (BoxesApp* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = value;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (self->priv->_uri);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->_uri = _tmp1_;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_notify ((GObject *) self, "uri");
#line 6060 "app.c"
}


GVirConnection* boxes_app_get_default_connection (BoxesApp* self) {
	GVirConnection* result;
	BoxesLibvirtBroker* _tmp0_ = NULL;
	BoxesLibvirtBroker* _tmp1_ = NULL;
	GVirConnection* _tmp2_ = NULL;
	GVirConnection* _tmp3_ = NULL;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_libvirt_broker_get_default ();
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = boxes_libvirt_broker_get_connection (_tmp1_, "QEMU Session");
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = _tmp2_;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_tmp1_);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = _tmp3_;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 6086 "app.c"
}


BoxesCollectionSource* boxes_app_get_default_source (BoxesApp* self) {
	BoxesCollectionSource* result;
	GHashTable* _tmp0_ = NULL;
	gconstpointer _tmp1_ = NULL;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->priv->sources;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = g_hash_table_lookup (_tmp0_, BOXES_APP_DEFAULT_SOURCE_NAME);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = (BoxesCollectionSource*) _tmp1_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 6104 "app.c"
}


GList* boxes_app_get_selected_items (BoxesApp* self) {
	GList* result;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesICollectionView* _tmp2_ = NULL;
	BoxesICollectionView* _tmp3_ = NULL;
	GList* _tmp4_ = NULL;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_get_main_window (self);
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = boxes_app_window_get_view (_tmp1_);
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = _tmp2_;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = boxes_icollection_view_get_selected_items (_tmp3_);
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = _tmp4_;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 6131 "app.c"
}


static void boxes_app_class_init (BoxesAppClass * klass) {
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_parent_class = g_type_class_peek_parent (klass);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_type_class_add_private (klass, sizeof (BoxesAppPrivate));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	((GApplicationClass *) klass)->startup = boxes_app_real_startup;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	((GApplicationClass *) klass)->activate = boxes_app_real_activate;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	((GApplicationClass *) klass)->command_line = boxes_app_real_command_line;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	((GApplicationClass *) klass)->shutdown = boxes_app_real_shutdown;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_app_get_property;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_app_set_property;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_app_finalize;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_MAIN_WINDOW, g_param_spec_object ("main-window", "main-window", "main-window", BOXES_TYPE_APP_WINDOW, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_URI, g_param_spec_string ("uri", "uri", "uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_DEFAULT_CONNECTION, g_param_spec_object ("default-connection", "default-connection", "default-connection", gvir_connection_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_DEFAULT_SOURCE, g_param_spec_object ("default-source", "default-source", "default-source", BOXES_TYPE_COLLECTION_SOURCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_SELECTED_ITEMS, g_param_spec_pointer ("selected-items", "selected-items", "selected-items", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_new ("ready", BOXES_TYPE_APP, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 6166 "app.c"
}


static void boxes_app_instance_init (BoxesApp * self) {
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv = BOXES_APP_GET_PRIVATE (self);
#line 6173 "app.c"
}


static void boxes_app_finalize (GObject* obj) {
	BoxesApp * self;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_APP, BoxesApp);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__g_list_free__g_object_unref0_0 (self->priv->windows);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (self->priv->_uri);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->collection);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_hash_table_unref0 (self->priv->brokers);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_hash_table_unref0 (self->priv->sources);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	G_OBJECT_CLASS (boxes_app_parent_class)->finalize (obj);
#line 6193 "app.c"
}


GType boxes_app_get_type (void) {
	static volatile gsize boxes_app_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_app_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesAppClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_app_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesApp), 0, (GInstanceInitFunc) boxes_app_instance_init, NULL };
		GType boxes_app_type_id;
		boxes_app_type_id = g_type_register_static (gtk_application_get_type (), "BoxesApp", &g_define_type_info, 0);
		g_once_init_leave (&boxes_app_type_id__volatile, boxes_app_type_id);
	}
	return boxes_app_type_id__volatile;
}


static void _vala_boxes_app_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesApp * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_APP, BoxesApp);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	switch (property_id) {
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_MAIN_WINDOW:
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_value_set_object (value, boxes_app_get_main_window (self));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_URI:
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_value_set_string (value, boxes_app_get_uri (self));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_DEFAULT_CONNECTION:
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_value_take_object (value, boxes_app_get_default_connection (self));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_DEFAULT_SOURCE:
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_value_set_object (value, boxes_app_get_default_source (self));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_SELECTED_ITEMS:
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_value_set_pointer (value, boxes_app_get_selected_items (self));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 6244 "app.c"
		default:
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 6250 "app.c"
	}
}


static void _vala_boxes_app_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesApp * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_APP, BoxesApp);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	switch (property_id) {
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_URI:
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_app_set_uri (self, g_value_get_string (value));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 6266 "app.c"
		default:
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 6272 "app.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



